(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Wolfram 14.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       154,          7]
NotebookDataLength[    199054,       5094]
NotebookOptionsPosition[    153454,       4514]
NotebookOutlinePosition[    159875,       4651]
CellTagsIndexPosition[    159832,       4648]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Wolfram Language code for arXiv preprint 2410.01456", "Chapter",
 Editable->False,
 ShowAutoSpellCheck->
  False,ExpressionUUID->"18a7f091-052c-4791-8874-96debaa08d49"],

Cell[CellGroupData[{

Cell["\<\
Moments of the cot function, central factorial numbers and their links with \
the Dirichlet eta function at odd integers\
\>", "Title",
 Editable->False,
 ShowAutoSpellCheck->
  False,ExpressionUUID->"3b9db973-5707-42b2-bf00-2b91c8f768e8"],

Cell[TextData[{
 ButtonBox["arXiv page \[RightGuillemet] ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/2410.01456"], None},
  ButtonNote->"https://arxiv.org/abs/2410.01456"],
 "    ",
 StyleBox["|",
  FontColor->GrayLevel[0.5]],
 "     ",
 ButtonBox["TeX file \[RightGuillemet] ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://https:/www.internalcloud.wolfram.com/env/meng/\
ConvertArXivTeXSource/paper/2403.19118.tex"], None},
  ButtonNote->
   "https://https:/www.internalcloud.wolfram.com/env/meng/\
ConvertArXivTeXSource/paper/2403.19118.tex"],
 "    ",
 StyleBox["|",
  FontColor->GrayLevel[0.5]],
 "     ",
 ButtonBox["PDF file \[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/pdf/2403.19118"], None},
  ButtonNote->"https://arxiv.org/pdf/2403.19118"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://https:/www.internalcloud.wolfram.com/env/meng/\
ConvertArXivTeXSource/paper/2403.19118.tex"], None},
  ButtonNote->
   "https://https:/www.internalcloud.wolfram.com/env/meng/\
ConvertArXivTeXSource/paper/2403.19118.tex"],
 "    ",
 StyleBox["|",
  FontColor->GrayLevel[0.5]],
 "     ",
 Cell[BoxData[
  ButtonBox[
   TemplateBox[{
     GraphicsBox[{{
        Hue[0.55, 0.88, 0.65], 
        RectangleBox[{0, 0}]}, {
        GrayLevel[1], 
        AbsoluteThickness[1.5], 
        LineBox[{{0.4, 0.35}, {0.4, 0.85}}], 
        LineBox[{{0.15, 0.6}, {0.6, 0.6}}]}}, 
      ImageMargins -> {{0, 0}, {4, 0}}, ImageSize -> 10], 
     StyleBox[
     "\" Conversion Metadata\"", "Text", ShowStringCharacters -> False, 
      FontColor -> Hue[0.55, 0.88, 0.65], StripOnInput -> False]},
    "RowDefault"],
   Appearance->None,
   BaseStyle->"Text",
   ButtonFunction:>
    With[{$CellContext`cellObj = 
      CellObject["5645653e-ccec-4697-9098-fde9ce8a6620"]}, 
     MathLink`CallFrontEnd[
      FrontEnd`Value[
       FEPrivate`SetCellGroupOpen[$CellContext`cellObj, 
        If[
        CurrentValue[$CellContext`cellObj, "CellGroupOpen"] == Open, Closed, 
         Open]]]]],
   Evaluator->Automatic,
   Method->"Preemptive"]],
  Editable->False,
  ShowAutoSpellCheck->False,ExpressionUUID->
  "89e554f6-6d4b-4c5d-8fd7-846f1d4feca7"]
}], "Text",
 ShowCellBracket->False,
 CellMargins->{{68, 10}, {10, 
  8}},ExpressionUUID->"0020919c-39bc-413a-bf0f-c1bd8c9a07a9"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
 Editable->True,
 ShowAutoSpellCheck->
  False,ExpressionUUID->"3b6cf309-18e6-4339-8ea7-b8f5b68aac24"],

Cell[CellGroupData[{

Cell[TextData[{
 "eq:moment-int-cot",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"1bc2f818-af5b-408e-a6b8-5eb92fd266d2"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"b69f0414-b52f-44e6-9353-1d041dd5d7a5"],

Cell["\<\

C(m) \\eqdef \\frac{1}{m!}
\\int_0^\\pi \\frac{\\theta^{m}}{2} \\cot\\left(\\frac{\\theta}{2}\\right) \
d\\theta, \\quad m=1,2,\\ldots
\
\>", "rawTeX",ExpressionUUID->"3577d4ba-a678-4709-882a-06b1b8c0e1ca"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"fafc8a39-822a-4a47-a0a8-9d7d8c81949c"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"a69d0d75-0946-4a68-94d6-df96c670799c"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"f344b4ad-235a-43bc-8336-646d21e67138"],

Cell["\<\
The TeX expression for the moment of the cotangent function integrates a \
scaled power of \[Theta] times the cotangent of \[Theta]/2 over the interval \
from 0 to \[Pi]. The conversion accurately represents this integral in \
Wolfram Language, using `Integrate` for the definite integral and `Cot` for \
the cotangent. Subscript notation is used for the moment index.\
\>", "LLMComment",ExpressionUUID->"96af5f49-908d-4a88-96c7-c59d6f9e8dc3"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"1cbf56df-a8e2-4eb5-8666-\
d7e12246db17"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "m"], ":=", 
   FractionBox[
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"cot", "(", 
        FractionBox["\[Theta]", "2"], ")"}], " ", 
       SuperscriptBox["\[Theta]", "m"]}], 
      RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}], 
    RowBox[{"m", "!"}]]}], TraditionalForm]], "formattedWL",ExpressionUUID->\
"89e748ec-2584-45ce-8d2c-0ea26bf1a3f8"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"bbfb9149-da7d-4539-9c55-d4c2c54bbec6"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"Subscript", "[", 
     RowBox[{"C", ",", " ", "m"}], "]"}], " ", ":=", " ", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"Factorial", "[", "m", "]"}]}], " ", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Theta]", "^", "m"}], "/", "2"}], ")"}], " ", 
        RowBox[{"Cot", "[", 
         RowBox[{"\[Theta]", "/", "2"}], "]"}]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"\[Theta]", ",", " ", "0", ",", " ", "\[Pi]"}], "}"}]}], 
      "]"}]}]}], "\n"}]}]], "linearizedWL",ExpressionUUID->"1e2396d8-b8c7-\
460f-b5f5-13da11976268"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "eq:Cm-Series",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"624dd037-3830-46bf-95f1-4f039400a514"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"7d0766cb-ad27-4451-9ba0-0d7b2a8844ca"],

Cell["\<\

C(m) =  \\sum_{l=0}^{\\left\\lfloor \\frac{m}{2}\\right\\rfloor}  (-1)^l \
\\frac{\\pi^{m-2l}}{(m-2l)!} \\eta(2l+1)
+  \\frac{1 + (-1)^m}{2}
{(-1)^{\\left\\lfloor \\frac{m}{2}\\right\\rfloor}}\\zeta(m+1).    
\
\>", "rawTeX",ExpressionUUID->"ad8bfabd-8a4b-401a-a159-798dc9654ba9"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"14028d40-b306-4af2-a494-6b131f58f7ef"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"4e86228e-ddac-41c6-9b52-5e580ba71038"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"b45c23f5-845c-4292-97e8-8f498122ffb2"],

Cell["\<\
This expression for C(m) involves a summation over l from 0 to the floor of \
m/2. Each term in the sum scales \[Pi] to a power determined by m and l, \
divides by a factorial, and multiplies by the Dirichlet Eta function \
evaluated at odd integers. The second part of the expression involves the \
Riemann Zeta function. The translation to Wolfram Language correctly uses \
`Sum`, `DirichletEta`, and `Zeta`.\
\>", "LLMComment",ExpressionUUID->"71ab8558-ac6e-4906-8416-39a2adba5f12"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"7ae78e2a-a561-4dea-9768-\
57f1154334ab"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "m"], ":=", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"l", "=", "0"}], 
      TemplateBox[{
        FractionBox["m", "2"]},
       "Floor"]], 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "l"], " ", 
       TemplateBox[{
         RowBox[{
           RowBox[{"2", " ", "l"}], "+", "1"}]},
        "DirichletEta"], " ", 
       SuperscriptBox["\[Pi]", 
        RowBox[{"m", "-", 
         RowBox[{"2", " ", "l"}]}]]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m", "-", 
         RowBox[{"2", " ", "l"}]}], ")"}], "!"}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "m"], "+", "1"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], 
      TemplateBox[{
        FractionBox["m", "2"]},
       "Floor"]], " ", 
     TemplateBox[{
       RowBox[{"m", "+", "1"}]},
      "Zeta"]}]}]}], TraditionalForm]], "formattedWL",ExpressionUUID->\
"71600cba-7311-4a7c-9f0a-e6397b878639"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"2db4f1de-f2a3-438f-b473-46f7985196f4"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"Subscript", "[", 
     RowBox[{"C", ",", " ", "m"}], "]"}], " ", ":=", " ", 
    RowBox[{
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "^", "l"}], " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Pi]", "^", 
           RowBox[{"(", 
            RowBox[{"m", " ", "-", " ", 
             RowBox[{"2", " ", "l"}]}], ")"}]}], ")"}], "/", 
         RowBox[{"Factorial", "[", 
          RowBox[{"m", " ", "-", " ", 
           RowBox[{"2", " ", "l"}]}], "]"}]}], " ", 
        RowBox[{"DirichletEta", "[", 
         RowBox[{
          RowBox[{"2", " ", "l"}], " ", "+", " ", "1"}], "]"}]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"l", ",", " ", "0", ",", " ", 
         RowBox[{"Floor", "[", 
          RowBox[{"m", "/", "2"}], "]"}]}], "}"}]}], "]"}], " ", "+", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "^", "m"}]}], ")"}], "/", "2"}], ")"}],
       " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "^", 
       RowBox[{"Floor", "[", 
        RowBox[{"m", "/", "2"}], "]"}]}], " ", 
      RowBox[{"Zeta", "[", 
       RowBox[{"m", " ", "+", " ", "1"}], "]"}]}]}]}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"21f7e8d2-5604-478a-8c2f-\
ca505b83ae00"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "eq:Integral-power-Log",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"2564e784-320f-4840-aa39-ec0ba6178f22"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"d50e94aa-3fec-4986-a503-8e412c0de629"],

Cell["\<\

\\frac{1}{(j+1)^{l+1}} = \\frac{(-1)^l}{l!} \\int_0^1 x^{j} \\log^l(x) dx.
\
\>", "rawTeX",ExpressionUUID->"69aa5834-2095-4b38-b169-45d5efde406b"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"10897700-913e-4d22-b1fa-729703199022"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"46adde41-5d83-4f54-958a-9f3758edbc4f"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"583e7ec3-e937-465c-a3df-cacbae2b7a33"],

Cell["\<\
This TeX equation represents an identity involving an integral of x to the \
power of j times the log of x to the power of l. The conversion to Wolfram \
Language uses `Integrate` for the integral and `Log` for the logarithm \
function, with proper bounds and variable power representation.\
\>", "LLMComment",ExpressionUUID->"08fcda97-4fec-4d90-824b-f774392419e1"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"9ff461d4-a7db-446d-ac6a-\
030ea44f192a"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"j", "+", "1"}], ")"}], 
     RowBox[{"l", "+", "1"}]]], "\[LongEqual]", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "l"], " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "j"], " ", 
        RowBox[{
         SuperscriptBox["log", "l"], "(", "x", ")"}]}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], 
    RowBox[{"l", "!"}]]}], TraditionalForm]], "formattedWL",ExpressionUUID->\
"2ada1730-803b-4505-b2af-6ff0bff175a3"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"e80d3416-5884-4eb3-9dc2-e14b4dba2390"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"1", "/", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"j", " ", "+", " ", "1"}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"l", " ", "+", " ", "1"}], ")"}]}]}], " ", "==", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "^", "l"}], "/", 
      RowBox[{"Factorial", "[", "l", "]"}]}], " ", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "^", "j"}], " ", 
        RowBox[{
         RowBox[{"Log", "[", "x", "]"}], "^", "l"}]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"x", ",", " ", "0", ",", " ", "1"}], "}"}]}], "]"}]}]}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"ef647190-f0f0-4049-a3df-\
5df782b46fbd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "eq:C1kwithK1/eq:C0kwithK0",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"3473c4c4-d885-4c8a-b913-f70a526bca4f"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"1a1dd26f-dbaf-4434-a7dc-76e72eda5a13"],

Cell["\<\

\\Codd{k} &=& \\sum_{l=0}^k 2^{2l+1} \\frac{\\pi^{2k-2l}}{(2k-2l)!}
\\int_{C_{l}}  K_1(x_1\\ldots x_{l})
\\prod_{i=1}^{l} \\frac{\\log(x_i)dx_i}{1-\\prod_{m=1}^i \
x_m^2},\\label{eq:C1kwithK1}\\\\
\\Ceve{k+1} &=& \\sum_{l=0}^k \\frac{\\pi^{2k-2l}}{(2k-2l+1)!}
\\int_{C_{l}}  K_0(x_1 \\ldots x_{l})
\\prod_{i=1}^{l} \\frac{\\log(x_i)dx_i}{1-\\prod_{m=1}^i x_m \
}\\label{eq:C0kwithK0}
\
\>", "rawTeX",ExpressionUUID->"dbc963a1-8f07-44fd-83b2-4e8c4eb3b29f"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"4a640960-e5dd-4f5b-b828-ead6d4a54086"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"fa32cb65-b3ef-42cc-9b49-2779658d5e24"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"63d0b51b-4493-4cd4-a43c-6c16b48a22a4"],

Cell["\<\
The conversions for \\Codd{k} and \\Ceve{k+1} involve sums of integrals over \
products. Each integral is over a product of logarithmic terms divided by \
products of variables. The integrals are over the unit interval [0,1] for \
each variable. This complex expression structure was translated using `Sum`, \
`Product`, and `Integrate` in Wolfram Language, carefully handling the \
product limits and integral bounds.


```
## [TeXSectionID]Equation Conversion from TeX to Wolfram \
Language[/TeXSectionID]
```\
\>", "LLMComment",ExpressionUUID->"b08c3633-319a-44fa-9bff-8864005f00a6"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"f5bc7dc9-2cae-48db-8141-\
586ac93eaf6a"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"not", " ", "available"}], " ", "*)"}]], "formattedWL",ExpressionUUI\
D->"e9d4191f-ae83-4a3f-83c6-6e8bb59104c7"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"35c9a308-ee52-4b68-90e1-edf3832ee744"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"LLM", " ", "result", " ", "with", " ", "syntax", " ", 
    RowBox[{"issue", ":"}]}], " ", "*)"}], "\n", "\n", 
  RowBox[{
   RowBox[{"{", "\n", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"Subscript", "[", 
       RowBox[{"Codd", ",", " ", "k"}], "]"}], " ", ":=", " ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"2", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "l"}], " ", "+", " ", "1"}], ")"}]}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Pi]", "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "k"}], " ", "-", " ", 
              RowBox[{"2", " ", "l"}]}], ")"}]}], "/", 
           RowBox[{"Factorial", "[", 
            RowBox[{
             RowBox[{"2", " ", "k"}], " ", "-", " ", 
             RowBox[{"2", " ", "l"}]}], "]"}]}], ")"}], " ", 
         RowBox[{"Integrate", "[", 
          RowBox[{
           RowBox[{"Product", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Log", "[", 
               RowBox[{"x", "[", "i", "]"}], "]"}], "/", 
              RowBox[{"(", 
               RowBox[{"1", " ", "-", " ", 
                RowBox[{"Product", "[", 
                 RowBox[{
                  RowBox[{"x", "[", "m", "]"}], ",", " ", 
                  RowBox[{"{", 
                   RowBox[{"m", ",", " ", "1", ",", " ", "i"}], "}"}]}], 
                 "]"}]}], ")"}]}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"i", ",", " ", "1", ",", " ", "l"}], "}"}]}], "]"}], 
           ",", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"x", "[", "1", "]"}], ",", " ", "0", ",", " ", "1"}], 
            "}"}], ",", " ", "...", ",", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"x", "[", "l", "]"}], ",", " ", "0", ",", " ", "1"}], 
            "}"}]}], "]"}]}], ",", "\n", "    ", 
        RowBox[{"{", 
         RowBox[{"l", ",", " ", "0", ",", " ", "k"}], "}"}]}], "]"}]}], ",", 
     "\n", "  ", 
     RowBox[{
      RowBox[{"Subscript", "[", 
       RowBox[{"Ceve", ",", " ", 
        RowBox[{"k", " ", "+", " ", "1"}]}], "]"}], " ", ":=", " ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Pi]", "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "k"}], " ", "-", " ", 
              RowBox[{"2", " ", "l"}]}], ")"}]}], "/", 
           RowBox[{"Factorial", "[", 
            RowBox[{
             RowBox[{"2", " ", "k"}], " ", "-", " ", 
             RowBox[{"2", " ", "l"}], " ", "+", " ", "1"}], "]"}]}], ")"}], 
         " ", 
         RowBox[{"Integrate", "[", 
          RowBox[{
           RowBox[{"Product", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Log", "[", 
               RowBox[{"x", "[", "i", "]"}], "]"}], "/", 
              RowBox[{"(", 
               RowBox[{"1", " ", "-", " ", 
                RowBox[{"Product", "[", 
                 RowBox[{
                  RowBox[{"x", "[", "m", "]"}], ",", " ", 
                  RowBox[{"{", 
                   RowBox[{"m", ",", " ", "1", ",", " ", "i"}], "}"}]}], 
                 "]"}]}], ")"}]}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"i", ",", " ", "1", ",", " ", "l"}], "}"}]}], "]"}], 
           ",", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"x", "[", "1", "]"}], ",", " ", "0", ",", " ", "1"}], 
            "}"}], ",", " ", "...", ",", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"x", "[", "l", "]"}], ",", " ", "0", ",", " ", "1"}], 
            "}"}]}], "]"}]}], ",", "\n", "    ", 
        RowBox[{"{", 
         RowBox[{"l", ",", " ", "0", ",", " ", "k"}], "}"}]}], "]"}]}]}], 
    "\n", "}"}], "\n"}]}]], "linearizedWL",ExpressionUUID->"f814aec9-aaaa-\
4be3-b0b3-3afef1b68a4f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "eq:C0-series",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"fa94404a-40e5-4200-9738-a57df9058ca9"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"c9011fb3-cb9b-4d21-9d86-48c4b4f33ba0"],

Cell["\<\

\\Codd{k} = \\sum_{l=0}^k (-1)^l \\frac{2^{2l+1} \\pi^{2k-2l}}{(2k-2l)!} \
\\Sodd{l}
\\quad\\mbox{ and }\\quad
\\Ceve{k+1} = \\sum_{l=0}^k  (-1)^{l}\\frac{\\pi^{2l}}{(2k-2l+1)!}  \\Seve{l} \

\
\>", "rawTeX",ExpressionUUID->"e83eea6f-712c-4efd-847a-592e99269f48"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"e16ffa5a-6da8-446d-8f28-426294224a8a"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"575dba3a-9126-4fe5-9221-d97ee48b542b"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"7e38bcaf-1c7c-4af1-a3bb-3badcb62d8eb"],

Cell["\<\
The sums over indexed variables are translated into Table constructs in \
Wolfram Language, ensuring correct representation of sequences. Subscripts \
are used for indexed variables in WL.\
\>", "LLMComment",ExpressionUUID->"52d69cf3-94d5-4433-b10e-903ddaec7e41"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"7d098b69-c63e-46c8-b2b5-\
a909597f149d"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"l", "=", "0"}], "k"], 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "l"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["2", 
          RowBox[{
           RowBox[{"2", " ", "l"}], "+", "1"}]], " ", 
         SuperscriptBox["\[Pi]", 
          RowBox[{
           RowBox[{"2", " ", "k"}], "-", 
           RowBox[{"2", " ", "l"}]}]]}], ")"}], " ", 
       SubscriptBox["S", 
        RowBox[{"1", ",", "l"}]]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "k"}], "-", 
         RowBox[{"2", " ", "l"}]}], ")"}], "!"}]]}], ",", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"l", "=", "0"}], "k"], 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "l"], " ", 
       SuperscriptBox["\[Pi]", 
        RowBox[{"2", " ", "l"}]], " ", 
       SubscriptBox["S", 
        RowBox[{"0", ",", "l"}]]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "k"}], "-", 
         RowBox[{"2", " ", "l"}], "+", "1"}], ")"}], "!"}]]}]}], "}"}], 
  TraditionalForm]], "formattedWL",ExpressionUUID->"b7833408-ed8a-45d7-aa43-\
78961929a399"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"3952b6a4-ece4-4896-a4a8-891fb4b6e9d0"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "^", "l"}], " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "l"}], " ", "+", " ", "1"}], ")"}]}], " ", 
           RowBox[{"Pi", "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "k"}], " ", "-", " ", 
              RowBox[{"2", " ", "l"}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"Factorial", "[", 
           RowBox[{
            RowBox[{"2", " ", "k"}], " ", "-", " ", 
            RowBox[{"2", " ", "l"}]}], "]"}], ")"}]}], " ", 
        RowBox[{"Subscript", "[", 
         RowBox[{"S", ",", " ", "1", ",", " ", "l"}], "]"}]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"l", ",", " ", "0", ",", " ", "k"}], "}"}]}], "]"}], ",", 
     "\n", " ", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "^", "l"}], " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Pi", "^", 
           RowBox[{"(", 
            RowBox[{"2", " ", "l"}], ")"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"Factorial", "[", 
           RowBox[{
            RowBox[{"2", " ", "k"}], " ", "-", " ", 
            RowBox[{"2", " ", "l"}], " ", "+", " ", "1"}], "]"}], ")"}]}], 
        " ", 
        RowBox[{"Subscript", "[", 
         RowBox[{"S", ",", " ", "0", ",", " ", "l"}], "]"}]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"l", ",", " ", "0", ",", " ", "k"}], "}"}]}], "]"}]}], "}"}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"df17c705-443b-4914-99f5-\
3639878ae5a7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Recursive series definitions for \\Sodd{k} and \\Seve{k}",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"b27182bc-09e5-4d08-9509-4f87a329f9f3"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"e1f420fc-c0f2-45aa-b363-fdfe7d137d47"],

Cell["\<\

\\Sodd{k} &=& \\sum_{j_0=0}^\\infty \\binom{2j_0}{j_0}
\\left(\\frac{1}{2}\\right)^{2j_0}\\frac{1}{(2j_0+1)^2}
\\sum_{j_1=j_0}^\\infty \\sum_{j_2=j_1}^\\infty \\ldots \\sum_{j_k=j_{k-1} }^\
\\infty 
\\frac{1}{(2j_1+1)^2\\ldots (2j_k+1)^2}\\\\
\\Seve{k} &=&\\frac{1}{2} \\sum_{j_0=1}^\\infty
\\frac{2^{2j_0}}{\\binom{2j_0}{j_0}}\\frac{1}{j_0^3}
\\sum_{j_1=j_0}^\\infty \\sum_{j_2=j_1}^\\infty \\ldots \\sum_{j_k=j_{k-1} }^\
\\infty 
\\frac{1}{j_1^2j_2^2 \\ldots j_k^2}
\
\>", "rawTeX",ExpressionUUID->"8719633c-a305-4b7d-9e1d-336950dc607a"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"1354402e-38d8-4da7-831c-4af2abf693e6"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"f667526e-cc5d-4e4d-8afe-3576b2a418cc"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"59c69bde-18ff-4db8-9075-c37134f93fbb"],

Cell["\<\
Multiple nested sums are represented using the Product function for the \
recursive terms, which accurately translates into nested loops in the Wolfram \
Language.\
\>", "LLMComment",ExpressionUUID->"5d8460cf-1a39-4e5d-9bad-10bf6dd29f1c"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"204d7aec-fc44-48e0-aa60-\
b0a9a929c28d"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"j0", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{
        RowBox[{"j", "(", "k", ")"}], "=", 
        RowBox[{"j", "(", 
         RowBox[{"k", "-", "1"}], ")"}]}], "\[Infinity]"], 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "2"], ")"}], 
         RowBox[{"2", " ", "j0"}]], " ", 
        TemplateBox[{
          RowBox[{"2", " ", "j0"}], "j0"},
         "Binomial"], " ", 
        RowBox[{
         UnderoverscriptBox["\[Product]", 
          RowBox[{"idx", "=", "j0"}], 
          RowBox[{"j", "(", 
           RowBox[{"k", "-", "1"}], ")"}]], 
         FractionBox["1", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{"j", "(", "idx", ")"}]}], "+", "1"}], ")"}], "2"]]}]}], 
       
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "j0"}], "+", "1"}], ")"}], "2"]]}]}], ",", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"j0", "=", "1"}], "\[Infinity]"], 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{
         RowBox[{"j", "(", "k", ")"}], "=", 
         RowBox[{"j", "(", 
          RowBox[{"k", "-", "1"}], ")"}]}], "\[Infinity]"], 
       FractionBox[
        RowBox[{
         SuperscriptBox["2", 
          RowBox[{"2", " ", "j0"}]], " ", 
         RowBox[{
          UnderoverscriptBox["\[Product]", 
           RowBox[{"idx", "=", "j0"}], 
           RowBox[{"j", "(", 
            RowBox[{"k", "-", "1"}], ")"}]], 
          FractionBox["1", 
           SuperscriptBox[
            RowBox[{"j", "(", "idx", ")"}], "2"]]}]}], 
        RowBox[{
         SuperscriptBox["j0", "3"], " ", 
         TemplateBox[{
           RowBox[{"2", " ", "j0"}], "j0"},
          "Binomial"]}]]}]}]}]}], "}"}], TraditionalForm]], "formattedWL",Expr\
essionUUID->"140dc3fe-38ee-4a1d-b75f-1d91fc42999e"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"5f9a4167-8ee5-4e27-9a04-c6cf2921e3d5"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Binomial", "[", 
         RowBox[{
          RowBox[{"2", " ", "j0"}], ",", " ", "j0"}], "]"}], " ", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", "2"}], ")"}], "^", 
          RowBox[{"(", 
           RowBox[{"2", " ", "j0"}], ")"}]}], "/", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "j0"}], " ", "+", " ", "1"}], ")"}], "^", 
          "2"}]}], " ", 
        RowBox[{"Product", "[", 
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               RowBox[{"j", "[", "idx", "]"}]}], " ", "+", " ", "1"}], ")"}], 
            "^", "2"}]}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"idx", ",", " ", "j0", ",", " ", 
            RowBox[{"j", "[", 
             RowBox[{"k", " ", "-", " ", "1"}], "]"}]}], "}"}]}], "]"}]}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"j0", ",", " ", "0", ",", " ", "Infinity"}], "}"}], ",", " ", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"j", "[", "k", "]"}], ",", " ", 
         RowBox[{"j", "[", 
          RowBox[{"k", " ", "-", " ", "1"}], "]"}], ",", " ", "Infinity"}], 
        "}"}]}], "]"}], ",", "\n", 
     RowBox[{
      RowBox[{"1", "/", "2"}], " ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", "^", 
            RowBox[{"(", 
             RowBox[{"2", " ", "j0"}], ")"}]}], ")"}], "/", 
          RowBox[{"Binomial", "[", 
           RowBox[{
            RowBox[{"2", " ", "j0"}], ",", " ", "j0"}], "]"}]}], " ", 
         RowBox[{"1", "/", 
          RowBox[{"j0", "^", "3"}]}], " ", 
         RowBox[{"Product", "[", 
          RowBox[{
           RowBox[{"1", "/", 
            RowBox[{
             RowBox[{"j", "[", "idx", "]"}], "^", "2"}]}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"idx", ",", " ", "j0", ",", " ", 
             RowBox[{"j", "[", 
              RowBox[{"k", " ", "-", " ", "1"}], "]"}]}], "}"}]}], "]"}]}], 
        ",", " ", 
        RowBox[{"{", 
         RowBox[{"j0", ",", " ", "1", ",", " ", "Infinity"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"j", "[", "k", "]"}], ",", " ", 
          RowBox[{"j", "[", 
           RowBox[{"k", " ", "-", " ", "1"}], "]"}], ",", " ", "Infinity"}], 
         "}"}]}], "]"}]}]}], "}"}], "\n"}]}]], "linearizedWL",ExpressionUUID->\
"f2d60143-1894-448c-a998-b213894b0e14"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Integral equations for \\int_0^1 \\frac{-\\log(x_0)}{\\sqrt{1-x_0^2}}dx_0 \
and similar",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"563f929d-fdf1-40bf-a84c-beb668ec1584"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"b89eb930-b3f1-43d8-a595-65e10976a32a"],

Cell["\<\

\\int_0^1 \\frac{-\\log(x_0)}{\\sqrt{1-x_0^2}}dx_0
=\\sum_{j_0=0}^\\infty \\binom{2j_0}{j_0} \
\\left(\\frac{1}{2}\\right)^{2j_0}\\frac{1}{(2j_0+1)^2}
= \\frac{\\pi}{2}\\log(2),
\
\>", "rawTeX",ExpressionUUID->"d757e206-40e6-4458-b9e2-16d52d628294"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"b656108f-eb57-4499-bfe5-8125a61004cb"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"c671ac0c-b5ac-42aa-8db1-383df0e64d11"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"7d7d383d-753b-4e57-9950-e7cd778a1063"],

Cell["\<\
Integral and summation are translated directly. The equation uses == to \
denote equality, ensuring clarity in expression relationships in WL.\
\>", "LLMComment",ExpressionUUID->"3fa20791-52c5-4b8f-a656-733ab239ba17"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"1a401644-ba41-4fcb-ba76-\
d3c6fb1dee06"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"log", "(", "x0", ")"}], 
       SqrtBox[
        RowBox[{"1", "-", 
         SuperscriptBox["x0", "2"]}]]]}], 
     RowBox[{"\[DifferentialD]", "x0"}]}]}], "\[LongEqual]", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"j0", "=", "0"}], "\[Infinity]"], 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "2"], ")"}], 
       RowBox[{"2", " ", "j0"}]], " ", 
      TemplateBox[{
        RowBox[{"2", " ", "j0"}], "j0"},
       "Binomial"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "j0"}], "+", "1"}], ")"}], "2"]]}], "\[LongEqual]", 
   
   RowBox[{
    FractionBox["1", "2"], " ", "\[Pi]", " ", 
    RowBox[{"log", "(", "2", ")"}]}]}], TraditionalForm]], "formattedWL",Expre\
ssionUUID->"3242ad52-a5a0-4b38-b21d-930afeb6386a"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"1abc6595-2bb3-41d0-81b0-aab465c7a8e7"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Log", "[", "x0", "]"}]}], "/", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", " ", "-", " ", 
         RowBox[{"x0", "^", "2"}]}], "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"x0", ",", " ", "0", ",", " ", "1"}], "}"}]}], "]"}], " ", "==",
     " ", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Binomial", "[", 
        RowBox[{
         RowBox[{"2", " ", "j0"}], ",", " ", "j0"}], "]"}], " ", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"2", " ", "j0"}], ")"}]}], "/", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "j0"}], " ", "+", " ", "1"}], ")"}], "^", 
         "2"}]}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"j0", ",", " ", "0", ",", " ", "Infinity"}], "}"}]}], "]"}], 
    " ", "==", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Pi", "/", "2"}], ")"}], " ", 
     RowBox[{"Log", "[", "2", "]"}]}]}], "\n"}]}]], "linearizedWL",ExpressionU\
UID->"c5d1fbba-07d2-444f-8a03-f08b1db6dad9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Advanced integral with arcsin^2",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"6acd5a34-336e-42ae-b6c2-ef558f68ec20"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"77f28df1-fd06-4f74-b77f-1acea106415d"],

Cell["\<\

\\int_0^1 \\frac{\\arcsin^2(\\sqrt{x_0})}{x_0}dx_0
= \\frac{1}{2} \\sum_{j_0=1}^\\infty
\\frac{2^{2j_0}}{\\binom{2j_0}{j_0}}\\frac{1}{j_0^3}
=\\frac{\\pi^2}{2}\\log(2)-\\frac{7}{3}\\eta(3)
\
\>", "rawTeX",ExpressionUUID->"90846dbf-b085-478e-9edd-e1af4d466d45"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"d95d4864-8e15-452f-9f24-096611bf4a2e"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"7b155fb7-d327-4d43-942b-53e115e4e6f8"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"a1207e5b-1e9d-47bd-86c0-f22528898bfb"],

Cell["\<\
The integral and series are directly translated, and the DirichletEta \
function is used for \\eta representation in WL, matching the function's \
properties in mathematical analysis.\
\>", "LLMComment",ExpressionUUID->"1e7a82ab-c7da-4fa3-b5a1-239e0d9fc19f"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"604a69c2-8663-4bc4-9c06-\
8ea155c40974"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["sin", 
         RowBox[{"-", "1"}]], "(", 
        SqrtBox["x0"], ")"}], "2"], "x0"], 
     RowBox[{"\[DifferentialD]", "x0"}]}]}], "\[LongEqual]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"j0", "=", "1"}], "\[Infinity]"], 
     FractionBox[
      SuperscriptBox["2", 
       RowBox[{"2", " ", "j0"}]], 
      RowBox[{
       SuperscriptBox["j0", "3"], " ", 
       TemplateBox[{
         RowBox[{"2", " ", "j0"}], "j0"},
        "Binomial"]}]]}]}], "\[LongEqual]", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox["\[Pi]", "2"], " ", 
     RowBox[{"log", "(", "2", ")"}]}], "-", 
    FractionBox[
     RowBox[{"7", " ", 
      TemplateBox[{"3"},
       "DirichletEta"]}], "3"]}]}], TraditionalForm]], "formattedWL",Expressio\
nUUID->"6aef41c6-a4bf-48e4-b7ba-1bab9830a7a0"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"fe7c161b-7f0c-478b-8074-6865b40f51cc"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"ArcSin", "[", 
         RowBox[{"Sqrt", "[", "x0", "]"}], "]"}], "^", "2"}], "/", "x0"}], 
      ",", " ", 
      RowBox[{"{", 
       RowBox[{"x0", ",", " ", "0", ",", " ", "1"}], "}"}]}], "]"}], " ", "==",
     " ", 
    RowBox[{
     RowBox[{"1", "/", "2"}], " ", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "^", 
           RowBox[{"(", 
            RowBox[{"2", " ", "j0"}], ")"}]}], ")"}], "/", 
         RowBox[{"Binomial", "[", 
          RowBox[{
           RowBox[{"2", " ", "j0"}], ",", " ", "j0"}], "]"}]}], " ", 
        RowBox[{"1", "/", 
         RowBox[{"j0", "^", "3"}]}]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"j0", ",", " ", "1", ",", " ", "Infinity"}], "}"}]}], "]"}]}],
     " ", "==", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Pi", "^", "2"}], "/", "2"}], ")"}], " ", 
      RowBox[{"Log", "[", "2", "]"}]}], " ", "-", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7", "/", "3"}], ")"}], " ", 
      RowBox[{"DirichletEta", "[", "3", "]"}]}]}]}], "\n"}]}]], "linearizedWL",\
ExpressionUUID->"2b4e282a-9fd6-452d-b86c-00e960d8ce22"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Evaluation of recursive series involving power of integers", \
"Subsection",
 Editable->True,
 ShowAutoSpellCheck->
  False,ExpressionUUID->"8ea3cef9-1b32-495d-aec9-c04d43f39bb7"],

Cell[CellGroupData[{

Cell[TextData[{
 "def:A1",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"8d96287d-f0fa-45f7-abb7-bc7c8b3c4545"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"256fd4e9-e627-4a7e-87fa-c51ac1942774"],

Cell["\<\

A_1(k) \\eqdef \\sum_{i_1=0}^\\infty \\frac{1}{(2i_1+1)^2}
\\sum_{i_2=i_1+1}^\\infty\\frac{1}{(2i_2+1)^2} \\ldots  \
\\sum_{i_k=i_{k-1}+1}^\\infty \\frac{1}{(2i_{k}+1)^2}
\
\>", "rawTeX",ExpressionUUID->"37ca19c2-938f-467a-b5f9-c5c3028119a6"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"e6e12699-f07c-4c92-a5bd-7521ed8f0324"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"0c9fef55-f535-45cd-8a7f-8af228f97c42"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"f41a1957-ee05-4cfb-b979-425867c465d6"],

Cell["\<\
Converted the nested summation over `i1, i2, ..., ik` with each `i` starting \
from the next index plus one. Represented sums in nested `Sum` and `Product` \
format.\
\>", "LLMComment",ExpressionUUID->"b4fbd6e0-8436-44ab-95da-ab11be4f9294"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"5de7782a-760c-4558-b09f-\
6336345842d0"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["A", "1"], "(", "k", ")"}], ":=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i1", "=", "0"}], "\[Infinity]"], 
    FractionBox[
     RowBox[{
      UnderoverscriptBox["\[Product]", 
       RowBox[{"idx", "=", "2"}], "k"], 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{
         SubscriptBox["i", "idx"], "=", 
         RowBox[{
          SubscriptBox["i", 
           RowBox[{"idx", "-", "1"}]], "+", "1"}]}], "\[Infinity]"], 
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SubscriptBox["i", "idx"]}], "+", "1"}], ")"}], "2"]]}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "i1"}], "+", "1"}], ")"}], "2"]]}]}], 
  TraditionalForm]], "formattedWL",ExpressionUUID->"2ff8b419-7d5c-49b8-8bc5-\
1faf2e239390"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"fa9548a6-8cfb-43ce-aa2e-5d63ca4f6f2d"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Subscript", "[", 
      RowBox[{"A", ",", " ", "1"}], "]"}], "[", "k", "]"}], " ", ":=", " ", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "i1"}], " ", "+", " ", "1"}], ")"}], "^", 
         "2"}]}], " ", 
       RowBox[{"Product", "[", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"1", "/", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"Subscript", "[", 
                 RowBox[{"i", ",", " ", "idx"}], "]"}]}], " ", "+", " ", 
               "1"}], ")"}], "^", "2"}]}], ",", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"i", ",", " ", "idx"}], "]"}], ",", " ", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"i", ",", " ", 
                RowBox[{"idx", " ", "-", " ", "1"}]}], "]"}], " ", "+", " ", 
              "1"}], ",", " ", "Infinity"}], "}"}]}], "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"idx", ",", " ", "2", ",", " ", "k"}], "}"}]}], "]"}]}], 
      ",", " ", 
      RowBox[{"{", 
       RowBox[{"i1", ",", " ", "0", ",", " ", "Infinity"}], "}"}]}], "]"}]}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"de929e4f-1b95-4e92-9a66-\
a067fc50fded"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "def:A0",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"657f6c41-8d4e-4027-b7b1-1c54b73c9652"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"63f0283e-c159-474f-9fa4-654404428877"],

Cell["\<\

A_0(k) \\eqdef \\sum_{i_1=1}^\\infty \\frac{1}{i_1^2}
\\sum_{i_2=i_1+1}^\\infty\\frac{1}{i_2^2} \\ldots  
\\sum_{i_k=i_{k-1}+1}^\\infty \\frac{1}{i_{k}^2},
\
\>", "rawTeX",ExpressionUUID->"506b6ff8-ebc3-4f33-87da-74909bb023b3"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"c215c14f-62b2-4619-9fa3-9f2d187a2521"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"0e55782e-f61d-4905-b22c-c1949f53af4a"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"4f4953d3-52e2-47a0-97ea-fa671660ffdc"],

Cell["\<\
Similar conversion method used as for `A_1(k)`, adapting to the sequence \
starting from `i1 = 1` and adjusting the limits accordingly.\
\>", "LLMComment",ExpressionUUID->"f55b7d14-2cb9-4806-9fb6-cd41b5e9212e"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"e17989f8-40af-4a57-8be6-\
9dd407b847e7"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["A", "0"], "(", "k", ")"}], ":=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i1", "=", "1"}], "\[Infinity]"], 
    FractionBox[
     RowBox[{
      UnderoverscriptBox["\[Product]", 
       RowBox[{"idx", "=", "2"}], "k"], 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{
         SubscriptBox["i", "idx"], "=", 
         RowBox[{
          SubscriptBox["i", 
           RowBox[{"idx", "-", "1"}]], "+", "1"}]}], "\[Infinity]"], 
       FractionBox["1", 
        SubsuperscriptBox["i", "idx", "2"]]}]}], 
     SuperscriptBox["i1", "2"]]}]}], TraditionalForm]], "formattedWL",Expressi\
onUUID->"9e415ce7-a10a-4c27-877b-f347d86d3037"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"b1dfa43f-e274-4f6d-a64b-21b9f4865093"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Subscript", "[", 
      RowBox[{"A", ",", " ", "0"}], "]"}], "[", "k", "]"}], " ", ":=", " ", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"i1", "^", "2"}]}], " ", 
       RowBox[{"Product", "[", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"1", "/", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"i", ",", " ", "idx"}], "]"}], "^", "2"}]}], ",", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"i", ",", " ", "idx"}], "]"}], ",", " ", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"i", ",", " ", 
                RowBox[{"idx", " ", "-", " ", "1"}]}], "]"}], " ", "+", " ", 
              "1"}], ",", " ", "Infinity"}], "}"}]}], "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"idx", ",", " ", "2", ",", " ", "k"}], "}"}]}], "]"}]}], 
      ",", " ", 
      RowBox[{"{", 
       RowBox[{"i1", ",", " ", "1", ",", " ", "Infinity"}], "}"}]}], "]"}]}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"9e5edf23-d93d-4375-bfd4-\
24f60ddcab35"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "eq:sum-2i+1-puiss-2l",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"78d14493-7379-4cb2-a83d-a8b9a9d0eae8"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"88b3cb7c-a079-495d-9c2c-0e0b7adfe28c"],

Cell["\<\

\\sum_{i=0}^\\infty \\frac{1}{(2i+1)^{2l}}
=\\sum_{i=1}^\\infty \\frac{1}{i^{2l} }
-\\frac{1}{2^{2l} } \\sum_{i=1}^\\infty \\frac{1}{i^{2l} }
= \\frac{2^{2l}-1}{2^{2l}} \\zeta(2l)
= (2^{2l}-1) \\frac{|B_{2l}|\\pi^{2l}}{2(2l)!},
\
\>", "rawTeX",ExpressionUUID->"e79abc68-c95e-464b-8624-e12d92544f82"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"707d5670-d272-40b7-a9cc-b050f837c93f"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"31c869cc-6b5d-462a-8d61-7a04891973ec"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"74358896-9dac-47df-b494-a9a035267b21"],

Cell["\<\
Converted the summation and equality chain directly, using `Zeta` for the \
zeta function and `BernoulliB` for the Bernoulli numbers.


## [TeXSectionID]Converted Equations from TeX to Wolfram \
Language[/TeXSectionID]\
\>", "LLMComment",ExpressionUUID->"7a3ac895-be4f-49c0-9c9f-658d822635b2"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"7983ece7-776f-458d-9fef-\
7ec31284fc44"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "0"}], "\[Infinity]"], 
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "i"}], "+", "1"}], ")"}], 
      RowBox[{"2", " ", "l"}]]]}], "\[LongEqual]", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "\[Infinity]"], 
     FractionBox["1", 
      SuperscriptBox["i", 
       RowBox[{"2", " ", "l"}]]]}], "-", 
    FractionBox[
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"i", "=", "1"}], "\[Infinity]"], 
      FractionBox["1", 
       SuperscriptBox["i", 
        RowBox[{"2", " ", "l"}]]]}], 
     SuperscriptBox["2", 
      RowBox[{"2", " ", "l"}]]]}], "\[LongEqual]", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{"2", " ", "l"}]], "-", "1"}], ")"}], " ", 
     TemplateBox[{
       RowBox[{"2", " ", "l"}]},
      "Zeta"]}], 
    SuperscriptBox["2", 
     RowBox[{"2", " ", "l"}]]], "\[LongEqual]", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{"2", " ", "l"}]], "-", "1"}], ")"}], " ", 
     SuperscriptBox["\[Pi]", 
      RowBox[{"2", " ", "l"}]], " ", 
     TemplateBox[{
       TemplateBox[{
         RowBox[{"2", " ", "l"}]}, "BernoulliB", SyntaxForm -> SubscriptBox]},
      
      "Abs"]}], 
    RowBox[{"2", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", "l"}], ")"}], "!"}]}]]}], 
  TraditionalForm]], "formattedWL",ExpressionUUID->"bdf03714-b235-4e7d-ab2e-\
2e4cbe4a691c"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"228493c0-9151-4d97-bd5b-7c923e56e04a"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "i"}], " ", "+", " ", "1"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"2", " ", "l"}], ")"}]}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"i", ",", " ", "0", ",", " ", "Infinity"}], "}"}]}], "]"}], 
    " ", "==", " ", 
    RowBox[{
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"i", "^", 
         RowBox[{"(", 
          RowBox[{"2", " ", "l"}], ")"}]}]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", "Infinity"}], "}"}]}], "]"}], 
     " ", "-", " ", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"2", "^", 
        RowBox[{"(", 
         RowBox[{"2", " ", "l"}], ")"}]}]}], " ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"i", "^", 
          RowBox[{"(", 
           RowBox[{"2", " ", "l"}], ")"}]}]}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", " ", "1", ",", " ", "Infinity"}], "}"}]}], 
       "]"}]}]}], " ", "==", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "^", 
         RowBox[{"(", 
          RowBox[{"2", " ", "l"}], ")"}]}], " ", "-", " ", "1"}], ")"}], "/", 
      
      RowBox[{"2", "^", 
       RowBox[{"(", 
        RowBox[{"2", " ", "l"}], ")"}]}]}], " ", 
     RowBox[{"Zeta", "[", 
      RowBox[{"2", " ", "l"}], "]"}]}], " ", "==", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "^", 
        RowBox[{"(", 
         RowBox[{"2", " ", "l"}], ")"}]}], " ", "-", " ", "1"}], ")"}], " ", 
     RowBox[{"Abs", "[", 
      RowBox[{"BernoulliB", "[", 
       RowBox[{"2", " ", "l"}], "]"}], "]"}], " ", 
     RowBox[{
      RowBox[{"Pi", "^", 
       RowBox[{"(", 
        RowBox[{"2", " ", "l"}], ")"}]}], "/", 
      RowBox[{"(", 
       RowBox[{"2", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", " ", "l"}], ")"}], "!"}]}], ")"}]}]}]}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"52f63d41-c25d-4876-bdaa-\
d5484a5de35a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "<text preceding the equation 1>",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"23b70ca8-48bf-4ec6-a8dc-bd55bbdef620"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"9e7d0c04-8c21-4a3f-80eb-33304bc32f33"],

Cell["\<\

g(z) = \\sum_{n=1}^\\infty (2^{2n}-1) |B_{2n}| \\frac{z^{2n}}{(2n)(2n)!}.
\
\>", "rawTeX",ExpressionUUID->"55bc079c-cd65-4839-afb6-22a3d5ff8ef7"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"4edbf2b6-d8f7-444c-ba0f-6c0284e684f7"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"29acd5b2-c775-4be5-b4e4-f0e299ef6879"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"1f04bbeb-8dec-4ec2-be54-986fd714153a"],

Cell["\<\
Converted the summation notation and used Abs[BernoulliB[2n]] for the \
absolute value of Bernoulli numbers in Wolfram Language.\
\>", "LLMComment",ExpressionUUID->"5fce4d9b-d44e-4592-9794-b07791aae9b1"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"666b57bc-bdd4-4594-8e10-\
b8269eebdc66"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"g", "(", "z_", ")"}], ":=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["2", 
         RowBox[{"2", " ", "n"}]], "-", "1"}], ")"}], " ", 
      SuperscriptBox["z", 
       RowBox[{"2", " ", "n"}]], " ", 
      TemplateBox[{
        TemplateBox[{
          RowBox[{"2", " ", "n"}]}, "BernoulliB", SyntaxForm -> SubscriptBox]},
       "Abs"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", "n"}], ")"}], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", " ", "n"}], ")"}], "!"}]}]]}]}], 
  TraditionalForm]], "formattedWL",ExpressionUUID->"d4192bed-e1cb-449f-baed-\
9f086e36e8d3"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"3aef0a9f-2a70-4e8f-9759-9a359417658b"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"g", "[", "z_", "]"}], " ", ":=", " ", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "^", 
          RowBox[{"(", 
           RowBox[{"2", " ", "n"}], ")"}]}], " ", "-", " ", "1"}], ")"}], " ", 
       RowBox[{"Abs", "[", 
        RowBox[{"BernoulliB", "[", 
         RowBox[{"2", " ", "n"}], "]"}], "]"}], " ", 
       RowBox[{
        RowBox[{"z", "^", 
         RowBox[{"(", 
          RowBox[{"2", " ", "n"}], ")"}]}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", " ", "n"}], ")"}], " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", " ", "n"}], ")"}], "!"}]}], ")"}]}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n", ",", " ", "1", ",", " ", "\[Infinity]"}], "}"}]}], 
     "]"}]}], "\n"}]}]], "linearizedWL",ExpressionUUID->"fd5702a6-4e0d-4497-\
b27f-4b59c7678bfa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "<text preceding the equation 2>",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"9d06fb17-b921-42f4-8f9d-80ef156cb489"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"7c138cab-5292-4bf5-82c8-e8e17ae55b79"],

Cell["\<\

zg'(z)=\\frac{z}{2} \\cot\\left( \\frac{z}{2} \\right)-z \\cot\\left(z \\right)
\
\>", "rawTeX",ExpressionUUID->"65446f7c-2fb3-4e9b-a9c7-8df72c6721cb"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"88ff4f25-40dc-40e2-97e9-d960c284a9b0"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"8fd66ce4-a0b7-4a6f-b008-8e473d015748"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"b1cd8602-f27a-4bd6-8562-c0449a20aac7"],

Cell["\<\
Expressed the derivative of g with respect to z using D[g[z], z] in Wolfram \
Language.\
\>", "LLMComment",ExpressionUUID->"1d0bc61a-47ef-438a-89c0-38fa5dc1c68a"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"616181cc-dfb0-4eba-a438-\
7c97548d7406"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"z", " ", 
    FractionBox[
     RowBox[{"\[PartialD]", 
      RowBox[{"g", "(", "z", ")"}]}], 
     RowBox[{"\[PartialD]", "z"}],
     MultilineFunction->None]}], "\[LongEqual]", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", "z", " ", 
     RowBox[{"cot", "(", 
      FractionBox["z", "2"], ")"}]}], "-", 
    RowBox[{"z", " ", 
     RowBox[{"cot", "(", "z", ")"}]}]}]}], TraditionalForm]], "formattedWL",Ex\
pressionUUID->"b77efc0f-a1d8-4c3f-99ea-6d440dc2d41f"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"8fc32ef4-4430-4e35-8dd7-47fb3212df6b"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"z", " ", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"g", "[", "z", "]"}], ",", " ", "z"}], "]"}]}], " ", "==", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"z", "/", "2"}], " ", 
      RowBox[{"Cot", "[", 
       RowBox[{"z", "/", "2"}], "]"}]}], " ", "-", " ", 
     RowBox[{"z", " ", 
      RowBox[{"Cot", "[", "z", "]"}]}]}]}], "\n"}]}]], "linearizedWL",Expressi\
onUUID->"444c1011-ec01-4c3c-8639-493b6186bf46"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "<text preceding the equation 3>",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"4007c9de-d078-42ba-8a48-39d18edf8f93"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"a7ec9b7e-efe3-4d14-81e4-a8b84e69728d"],

Cell["\<\

g(z) = \\log\\left(\\frac{\\sin(z/2)}{\\sin(z)} \\right)+\\log(2)= \
\\log\\left(\\frac{1}{\\cos(z/2)} \\right)
\
\>", "rawTeX",ExpressionUUID->"ec90d983-0d2f-4940-b445-c05bd2cdb90a"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"8eaa6b83-cc65-4287-a2a3-92aec4eacddd"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"54a9cbc3-73f5-4f2f-83ec-bb39648b7e98"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"f8ec84ee-4f99-49f7-9f17-3e48126981f4"],

Cell["\<\
Used Log for logarithm and Sin, Cos for trigonometric functions in Wolfram \
Language.\
\>", "LLMComment",ExpressionUUID->"b9f1ae18-75a8-4fde-a808-f0db36c01b82"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"ecd857fa-b509-48b4-8a60-\
af5f39d8d32c"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"g", "(", "z_", ")"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"log", "(", 
      FractionBox[
       RowBox[{"sin", "(", 
        FractionBox["z", "2"], ")"}], 
       RowBox[{"sin", "(", "z", ")"}]], ")"}], "+", 
     RowBox[{"log", "(", "2", ")"}]}], "\[LongEqual]", 
    RowBox[{"log", "(", 
     FractionBox["1", 
      RowBox[{"cos", "(", 
       FractionBox["z", "2"], ")"}]], ")"}]}]}], 
  TraditionalForm]], "formattedWL",ExpressionUUID->"0aa4eb2d-260b-4d80-a55e-\
f43af62a785f"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"e2687f79-9fd1-4a9c-80e5-552281e52d64"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"g", "[", "z_", "]"}], " ", ":=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Log", "[", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"z", "/", "2"}], "]"}], "/", 
        RowBox[{"Sin", "[", "z", "]"}]}], "]"}], " ", "+", " ", 
      RowBox[{"Log", "[", "2", "]"}]}], " ", "==", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"1", "/", 
       RowBox[{"Cos", "[", 
        RowBox[{"z", "/", "2"}], "]"}]}], "]"}]}]}], "\n"}]}]], "linearizedWL",\
ExpressionUUID->"c0e31539-2366-47d3-9ab1-6a511b4aba58"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "<text preceding the equation 4>",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"4cd1b13f-c533-4667-97aa-2bf8f331d980"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"5cd8a6d7-6bc4-4557-91a6-49a66cc7ed32"],

Cell["\<\

\\Reve{k} = 2 (2^{2k-1} -1) \\frac{|B_{2k}|\\pi^{2k}}{(2k)!}.
\
\>", "rawTeX",ExpressionUUID->"2a0eb0f2-956a-4df9-86c9-253439cee8f4"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"cfc64473-9335-4d46-af9e-4e11f747f717"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"b887baec-51c5-4ef5-8e77-ea0f8f5401d0"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"bdee635a-9ebc-4a21-b86b-f28dc06badb3"],

Cell["\<\
Corrected the use of Bernoulli numbers and factorial to comply with Wolfram \
Language syntax.\
\>", "LLMComment",ExpressionUUID->"706691b7-77a3-4939-82de-a3cd17a0b284"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"c6a15bf1-cf42-478a-a16f-\
c891d07892ed"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Reve", "(", "k_", ")"}], ":=", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{
         RowBox[{"2", " ", "k"}], "-", "1"}]], "-", "1"}], ")"}], " ", 
     SuperscriptBox["\[Pi]", 
      RowBox[{"2", " ", "k"}]], " ", 
     TemplateBox[{
       TemplateBox[{
         RowBox[{"2", " ", "k"}]}, "BernoulliB", SyntaxForm -> SubscriptBox]},
      
      "Abs"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", " ", "k"}], ")"}], "!"}]]}], 
  TraditionalForm]], "formattedWL",ExpressionUUID->"15c7b6b0-e5ef-4b12-b427-\
f7fcc84dbfa2"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"94d4d9e9-04c3-44c0-9cdc-b4ad4e2f52f4"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"Reve", "[", "k_", "]"}], " ", ":=", " ", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "k"}], " ", "-", " ", "1"}], ")"}]}], " ", "-", 
       " ", "1"}], ")"}], " ", 
     RowBox[{"Abs", "[", 
      RowBox[{"BernoulliB", "[", 
       RowBox[{"2", " ", "k"}], "]"}], "]"}], " ", 
     RowBox[{
      RowBox[{"Pi", "^", 
       RowBox[{"(", 
        RowBox[{"2", " ", "k"}], ")"}]}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", " ", "k"}], ")"}], "!"}], ")"}]}]}]}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"7a0390fa-5d2b-4a89-95b0-\
2879671e10db"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "<text preceding the equation 5>",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"73e41274-3475-4712-9d51-9d276f111618"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"29d9ecbc-334a-41c0-85c8-10c40af90beb"],

Cell["\<\

\\Reve{k} = \\frac{1}{k!} \\sum_{\\bpi\\in \\calP(k)} \
a(\\bpi)\\prod_{l=1}^{k} \\zeta(2l)^{\\pi_l}.
\
\>", "rawTeX",ExpressionUUID->"e6eba17e-5473-402a-b591-14af8566f01b"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"670b86a7-cd0e-493b-85b6-2077375380b2"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"1d500c8b-da0c-4ad5-8de2-24f85a151d46"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"4f30a8fc-f2de-414f-a14a-9a5055c5d072"],

Cell["\<\
Converted the sum and product notation, used Zeta function directly available \
in Wolfram Language.\
\>", "LLMComment",ExpressionUUID->"ae09e91c-e1e1-4e88-831b-b7277de6fb26"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"c4a0d941-eceb-4998-8eea-\
e0950af8bdb2"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Reve", "(", "k_", ")"}], ":=", 
   FractionBox[
    RowBox[{
     UnderoverscriptBox["\[Sum]", "\[Pi]", 
      RowBox[{"calP", "(", "k", ")"}]], 
     RowBox[{
      RowBox[{"a", "(", "\[Pi]", ")"}], " ", 
      RowBox[{
       UnderoverscriptBox["\[Product]", 
        RowBox[{"l", "=", "1"}], "k"], 
       SuperscriptBox[
        TemplateBox[{
          RowBox[{"2", " ", "l"}]},
         "Zeta"], 
        RowBox[{"\[Pi]", "(", "l", ")"}]]}]}]}], 
    RowBox[{"k", "!"}]]}], TraditionalForm]], "formattedWL",ExpressionUUID->\
"a7f016e7-ff51-4a40-8d1c-1768f8768049"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"1845bd79-249b-4f9d-88b6-455bf2c3301c"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"Reve", "[", "k_", "]"}], " ", ":=", " ", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"k", "!"}]}], " ", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"a", "[", "\[Pi]", "]"}], " ", 
        RowBox[{"Product", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Zeta", "[", 
            RowBox[{"2", " ", "l"}], "]"}], "^", 
           RowBox[{"\[Pi]", "[", "l", "]"}]}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"l", ",", " ", "1", ",", " ", "k"}], "}"}]}], "]"}]}], ",",
        " ", 
       RowBox[{"{", 
        RowBox[{"\[Pi]", ",", " ", 
         RowBox[{"calP", "[", "k", "]"}]}], "}"}]}], "]"}]}]}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"bc183828-651d-4546-bbd3-\
b489233ed8d6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "<text preceding the equation 6>",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"8133a1ed-1349-492c-bcb2-8f5c85a21c71"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"0a2abe2d-5027-4437-a7b1-f745379167dd"],

Cell["\<\

\\Reve{k} = {(2\\pi)^{2k}} \\sum_{\\bpi\\in \\calP(k)} \\prod_{l=1}^{k} \
\\frac{1}{\\pi_l!} \\left(\\frac{|B_{2l}|}{2l(2l)!} \\right)^{\\pi_l}
={(2\\pi)^{2k}} \\sum_{\\bpi\\in \\calP(k)} \\binom{l(\\bpi)}{\\pi_1,\\ldots,\
\\pi_k} \\frac{1}{l(\\bpi)!}
\\prod_{l=1}^{k}
\\left[\\frac{|B_{2l}|}{2l(2l)!}\\right]^{\\pi_l}.
\
\>", "rawTeX",ExpressionUUID->"5c7ea17f-8be6-4c42-b9f8-e6adba1e9ceb"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"0658a880-07a1-41c7-9b23-3c700bafcbaf"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"4c666770-0bf9-4a6f-a83c-61733ca6a9c5"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"122d4bf5-5a4f-4002-a873-42608bf735de"],

Cell["\<\
Converted the summation and product using appropriate Wolfram Language \
functions and syntax.\
\>", "LLMComment",ExpressionUUID->"f2e478e1-fb16-41b5-96ef-49d014a4151d"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"f52956a6-c48c-418e-9d10-\
e269fc0cdc8b"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Reve", "(", "k_", ")"}], ":=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"2", " ", "\[Pi]"}], ")"}], 
     RowBox[{"2", " ", "k"}]], " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", "\[Pi]", 
      RowBox[{"calP", "(", "k", ")"}]], 
     RowBox[{
      UnderoverscriptBox["\[Product]", 
       RowBox[{"l", "=", "1"}], "k"], 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          TemplateBox[{
            TemplateBox[{
              RowBox[{"2", " ", "l"}]}, "BernoulliB", SyntaxForm -> 
             SubscriptBox]},
           "Abs"], 
          RowBox[{"2", " ", "l", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", " ", "l"}], ")"}], "!"}]}]], ")"}], 
        RowBox[{"\[Pi]", "(", "l", ")"}]], 
       RowBox[{
        RowBox[{"\[Pi]", "(", "l", ")"}], "!"}]]}]}]}]}], 
  TraditionalForm]], "formattedWL",ExpressionUUID->"144a8b8c-fc5f-440a-9658-\
32e3563b1d44"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"91a85317-90bc-439c-a39d-25f8e7bcd706"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"Reve", "[", "k_", "]"}], " ", ":=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", "Pi"}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"2", " ", "k"}], ")"}]}], " ", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{"Product", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{
            RowBox[{"\[Pi]", "[", "l", "]"}], "!"}]}], " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{"BernoulliB", "[", 
               RowBox[{"2", " ", "l"}], "]"}], "]"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", " ", "l", " ", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", " ", "l"}], ")"}], "!"}]}], ")"}]}], ")"}], "^", 
           RowBox[{"\[Pi]", "[", "l", "]"}]}]}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"l", ",", " ", "1", ",", " ", "k"}], "}"}]}], "]"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{"\[Pi]", ",", " ", 
         RowBox[{"calP", "[", "k", "]"}]}], "}"}]}], "]"}]}]}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"f4aaaf54-c5f6-48a9-868e-\
48d88a87dd45"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "<text preceding the equation 7>",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"7376881b-ee86-4ea2-a766-3b3c1597f59a"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"34b01201-8cdb-46fc-b975-22451375c7c6"],

Cell["\<\

\\log(z/2) - \\log(\\sin(z/2)) = \\sum_{i=1}^\\infty \\frac{|B_{2n}|}{2n} \
\\frac{z^{2n}}{(2n)!}
\
\>", "rawTeX",ExpressionUUID->"ff1e3876-f77e-4729-bad1-204304aeb6fe"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"85d61e9a-b264-4793-83b6-1c686ca84c42"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"46cb741f-4174-40e5-b3f5-26762fce2a3d"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"74c90bb3-499d-457e-afb3-c7b1f2935045"],

Cell["\<\
Expressed the infinite series and logarithm function in Wolfram Language.


```
## [TeXSectionID]Equations from the TeX source code[/TeXSectionID]
```\
\>", "LLMComment",ExpressionUUID->"075b68ad-c28e-49d9-b4dc-bab709786d50"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"f1c573d9-d20e-4788-85b0-\
7d2fbf1c87f5"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"log", "(", 
     FractionBox["z", "2"], ")"}], "-", 
    RowBox[{"log", "(", 
     RowBox[{"sin", "(", 
      FractionBox["z", "2"], ")"}], ")"}]}], "\[LongEqual]", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    FractionBox[
     RowBox[{
      SuperscriptBox["z", 
       RowBox[{"2", " ", "n"}]], " ", 
      TemplateBox[{
        TemplateBox[{
          RowBox[{"2", " ", "n"}]}, "BernoulliB", SyntaxForm -> SubscriptBox]},
       "Abs"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", "n"}], ")"}], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", " ", "n"}], ")"}], "!"}]}]]}]}], 
  TraditionalForm]], "formattedWL",ExpressionUUID->"c8af3db5-cb18-4aac-88df-\
f9066c967d64"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"33d9a9c9-1a0b-44ad-8375-22a42a2d98bb"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Log", "[", 
      RowBox[{"z", "/", "2"}], "]"}], " ", "-", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"Sin", "[", 
       RowBox[{"z", "/", "2"}], "]"}], "]"}]}], " ", "==", " ", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"BernoulliB", "[", 
          RowBox[{"2", " ", "n"}], "]"}], "]"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", "n"}], ")"}]}], " ", 
       RowBox[{
        RowBox[{"z", "^", 
         RowBox[{"(", 
          RowBox[{"2", " ", "n"}], ")"}]}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", " ", "n"}], ")"}], "!"}], ")"}]}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n", ",", " ", "1", ",", " ", "\[Infinity]"}], "}"}]}], 
     "]"}]}], "\n"}]}]], "linearizedWL",ExpressionUUID->"119a0af0-37a6-470e-\
abd2-a344486d6df7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "First series expression",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"21518339-73c1-44c0-a60f-56dab297d8c0"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"0581b741-8bcd-4ed0-b8b4-13a3cd08e9b8"],

Cell["\<\

\\sum_{i_1=0}^\\infty \\frac{1}{(2i_1+1)^2}
\\sum_{i_2=i_1+1}^\\infty\\frac{1}{(2i_2+1)^2} \\ldots  \
\\sum_{i_k=i_{k-1}+1}^\\infty \\frac{1}{(2i_k+1)^2}
\
\>", "rawTeX",ExpressionUUID->"7ab24720-e405-4fd2-9b51-52f572f6f341"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"9bd652cd-ef92-4b70-a65c-abd40695d1bd"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"313afa3b-95c8-443e-85ed-cc2d9fcb4e91"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"c46736db-600b-437f-82d0-37f42c5269be"],

Cell["\<\
This is a conversion of a nested series into Wolfram Language using `Sum`. \
The use of `Nest` is to handle the recursive definition of summation start \
indices.\
\>", "LLMComment",ExpressionUUID->"25f0afaa-ad32-4a61-95d1-abd2297e0735"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"904b7dcc-6379-4131-a1f0-\
50dda51b33e0"],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"i1", "=", "0"}], "\[Infinity]"], 
   FractionBox[
    RowBox[{"Nest", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"ik", "=", 
          RowBox[{
           RowBox[{"i", "(", 
            RowBox[{"k", "-", "1"}], ")"}], "+", "1"}]}], "\[Infinity]"], 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "ik"}], "+", "1"}], ")"}], "2"]]}], "&"}], ",", 
      "1", ",", 
      RowBox[{"k", "-", "1"}]}], "]"}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "i1"}], "+", "1"}], ")"}], "2"]]}], 
  TraditionalForm]], "formattedWL",ExpressionUUID->"337c7bb8-8597-438c-812e-\
65d25ca76ac8"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"de791c4e-455e-4304-9f76-57c69721db9d"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "i1"}], " ", "+", " ", "1"}], ")"}], "^", "2"}]}],
       " ", 
      RowBox[{"Nest", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"1", "/", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "ik"}], " ", "+", " ", "1"}], ")"}], "^", 
             "2"}]}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"ik", ",", " ", 
             RowBox[{
              RowBox[{"i", "[", 
               RowBox[{"k", " ", "-", " ", "1"}], "]"}], " ", "+", " ", "1"}],
              ",", " ", "Infinity"}], "}"}]}], "]"}], " ", "&"}], ",", " ", 
        "1", ",", " ", 
        RowBox[{"k", " ", "-", " ", "1"}]}], "]"}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i1", ",", " ", "0", ",", " ", "Infinity"}], "}"}]}], "]"}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"522350b0-3eac-4d35-878e-\
40e3f6aaffda"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Series expansion representation",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"46a4fc8f-0ebe-468a-89bf-b988f059e195"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"938818fd-88c5-4c01-8874-f781525eb932"],

Cell["\<\

\\frac{1}{1- x_1^2x_2^2\\ldots x_k^2} = \\sum_{i_1=0}^\\infty \
(x_1^2x_2^2\\ldots x_k^2)^{i_1}
\
\>", "rawTeX",ExpressionUUID->"daf35ea3-6722-4869-ae2a-e1402aed3d32"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"e6af4f6d-9cce-4a5d-b72e-c7957e00b11e"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"3949540d-c009-4f41-80fe-7c70a3cdfce2"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"9264d311-4f75-4db9-bf6c-5800499f9439"],

Cell["\<\
The TeX expression is converted by breaking down the formula into a product \
inside a sum, using `Product` and `Sum` in WL to accurately represent the \
series and product over indices.\
\>", "LLMComment",ExpressionUUID->"964808c3-b818-44ac-bc78-b3796d3371c3"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"0b2e3dea-04e6-4960-9f1a-\
e2e5007efa44"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", "-", 
     RowBox[{
      UnderoverscriptBox["\[Product]", 
       RowBox[{"i", "=", "1"}], "k"], 
      SuperscriptBox[
       RowBox[{"x", "(", "i", ")"}], "2"]}]}]], "\[LongEqual]", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i1", "=", "0"}], "\[Infinity]"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       UnderoverscriptBox["\[Product]", 
        RowBox[{"i", "=", "1"}], "k"], 
       SuperscriptBox[
        RowBox[{"x", "(", "i", ")"}], "2"]}], ")"}], "i1"]}]}], 
  TraditionalForm]], "formattedWL",ExpressionUUID->"a3fd9fe2-c72e-47db-b67d-\
526df7f42a4e"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"eb78267b-ff68-4e06-a809-a9c253033ef4"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{"Product", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "i", "]"}], "^", "2"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"i", ",", " ", "1", ",", " ", "k"}], "}"}]}], "]"}]}], 
      ")"}]}], " ", "==", " ", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Product", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "i", "]"}], "^", "2"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"i", ",", " ", "1", ",", " ", "k"}], "}"}]}], "]"}], "^", 
       "i1"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"i1", ",", " ", "0", ",", " ", "Infinity"}], "}"}]}], "]"}]}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"e47921d0-1a52-4432-8779-\
c05ba72a960a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Nested integral and series expression",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"239cb556-1331-4a89-b59a-20d40b45e3e7"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"b830ce06-a129-48c3-b1bc-cbaca540f3fa"],

Cell["\<\

\\sum_{i_1=0}^{\\infty} \\frac{1}{(2i_1+1)^2} \\int_{C_{k-1} }\\frac{ \
(-1)^{k-1} \\prod_{i=2}^{k} x_i^{2(i-1)+2i_1}  \\log(x_i) dx_i}
{ \\prod_{i=2}^{k} \\left(1-\\prod_{m=i}^k x_m^2\\right) }
\
\>", "rawTeX",ExpressionUUID->"2728f194-f028-4b41-ac67-acf2aec1eb91"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"075f2b3b-e710-4d2c-aab0-e54ab47fcdb2"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"69545965-95b2-4364-9a5b-6efe5c7b2d95"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"a0797fb4-4abf-4883-97c1-2e3bba037bbf"],

Cell["\<\
Converted the given TeX expression into a WL expression using `Sum` and \
`Integrate`. The use of `Product` inside the integral and sum helps to \
dynamically construct the polynomials and denominators as represented in the \
TeX code.\
\>", "LLMComment",ExpressionUUID->"017a0042-90cf-4736-b32b-33538aac18eb"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"2aaa3f5c-b52c-4bf8-8d20-\
fdc056ca641b"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"not", " ", "available"}], " ", "*)"}]], "formattedWL",ExpressionUUI\
D->"05eab87b-12d6-4554-9c09-95354f9a0e0e"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"e4598c8d-0039-4464-b08d-8bbe6a373f98"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"LLM", " ", "result", " ", "with", " ", "syntax", " ", 
    RowBox[{"issue", ":"}]}], " ", "*)"}], "\n", "\n", 
  RowBox[{
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "i1"}], " ", "+", " ", "1"}], ")"}], "^", "2"}]}],
       " ", 
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "^", 
          RowBox[{"(", 
           RowBox[{"k", " ", "-", " ", "1"}], ")"}]}], " ", 
         RowBox[{
          RowBox[{"Product", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"x", "[", "i", "]"}], "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{"i", " ", "-", " ", "1"}], ")"}]}], " ", "+", " ", 
                RowBox[{"2", " ", "i1"}]}], ")"}]}], " ", 
             RowBox[{"Log", "[", 
              RowBox[{"x", "[", "i", "]"}], "]"}]}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "2", ",", " ", "k"}], "}"}]}], "]"}], "/", 
          RowBox[{"Product", "[", 
           RowBox[{
            RowBox[{"1", " ", "-", " ", 
             RowBox[{"Product", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"x", "[", "m", "]"}], "^", "2"}], ",", " ", 
               RowBox[{"{", 
                RowBox[{"m", ",", " ", "i", ",", " ", "k"}], "}"}]}], "]"}]}],
             ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "2", ",", " ", "k"}], "}"}]}], "]"}]}]}], 
        ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "[", "2", "]"}], ",", " ", "0", ",", " ", "1"}], "}"}],
         ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "[", "3", "]"}], ",", " ", "0", ",", " ", "1"}], "}"}],
         ",", " ", "...", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "[", "k", "]"}], ",", " ", "0", ",", " ", "1"}], 
         "}"}]}], "]"}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i1", ",", " ", "0", ",", " ", "Infinity"}], "}"}]}], "]"}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"ff5d450f-1024-486d-801c-\
e2bb130a3273"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Integral representation of the central factorial numbers (cfns)\
\>", "Subsection",
 Editable->True,
 ShowAutoSpellCheck->
  False,ExpressionUUID->"df3d0b01-3dcd-47b1-8bb5-0daeb258327f"],

Cell[CellGroupData[{

Cell[TextData[{
 "eq:gen-funct-cfn",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"23114649-ce7f-49a3-8b7c-5ccbe887a6cf"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"3b44a57c-b771-4fcb-9f28-da47dc27182f"],

Cell["\<\

\\frac{1}{m!} \
\\left[2\\;\\mathrm{arcsin}\\left(\\frac{z}{2}\\right)\\right]^{m}
=\\sum_{n=m}^\\infty  |t(n,m)|  \\frac{z^{n}}{n!}.
\
\>", "rawTeX",ExpressionUUID->"8ffb58e6-7e93-468d-87ed-6723e28c4393"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"ef4a963d-4832-44f2-b52f-e010fe43e421"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"4e02faca-d61b-4780-9460-3385b4f7fe41"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"9425e07e-8b75-488b-8f64-6c85feab8997"],

Cell["\<\
The TeX expression involving a power function, ArcSin function, and a series \
representation is converted to Wolfram Language using Sum for the series and \
keeping function names and operations aligned with WL's syntax.\
\>", "LLMComment",ExpressionUUID->"573229e3-5cea-49c8-81cd-de4f9498420f"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"f0e58120-aeaf-41fb-ace9-\
5bc6585ba8f9"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["sin", 
         RowBox[{"-", "1"}]], "(", 
        FractionBox["z", "2"], ")"}]}], ")"}], "m"], 
    RowBox[{"m", "!"}]], "\[LongEqual]", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "m"}], "\[Infinity]"], 
    FractionBox[
     RowBox[{
      SuperscriptBox["z", "n"], " ", 
      TemplateBox[{
        RowBox[{"t", "(", 
          RowBox[{"n", ",", "m"}], ")"}]},
       "Abs"]}], 
     RowBox[{"n", "!"}]]}]}], TraditionalForm]], "formattedWL",ExpressionUUID->\
"05b1a532-0102-4d12-bd69-6a22d6abceb2"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"5b730e5a-fdcd-44ec-ac93-19991efcda02"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"m", "!"}]}], " ", "*", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"ArcSin", "[", 
         RowBox[{"z", "/", "2"}], "]"}]}], ")"}], "^", "m"}]}], " ", "==", 
    " ", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"t", "[", 
         RowBox[{"n", ",", " ", "m"}], "]"}], "]"}], "*", 
       RowBox[{
        RowBox[{"z", "^", "n"}], "/", 
        RowBox[{"n", "!"}]}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n", ",", " ", "m", ",", " ", "Infinity"}], "}"}]}], "]"}]}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"0c4c23e4-00c4-4f83-9463-\
f76e6ebcaf0b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "eq:gen-funct-cfn0",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"2fd2ab76-9759-477a-9c60-8c0fafb294db"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"039460b5-0ab9-46eb-812b-127d69d726a4"],

Cell["\<\

\\frac{1}{(2k)!} \
\\left[2\\;\\mathrm{arcsin}\\left(\\frac{z}{2}\\right)\\right]^{2k}
&=&\\sum_{n=k}^\\infty  t_0(k,n)  \\frac{z^{2n}}{(2n)!}, \\quad k\\geq 1
\
\>", "rawTeX",ExpressionUUID->"92bbef96-2176-4d62-b37d-bcaaefaeac56"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"e15ae892-d1fd-4017-9726-6016554109b4"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"1ac017af-74a6-4fc3-814a-83f315100b94"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"7bc78534-75f0-4c8e-8e72-38261ab1e5c6"],

Cell["\<\
I converted the factorial notation and series into Wolfram Language format, \
using the definition of functions and Sum for infinite series. Subscript \
notation for t0 is written as a function t0[k, n].\
\>", "LLMComment",ExpressionUUID->"16f02d13-0e7f-47e3-b74b-ea06d5ad067e"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"00a71bd4-ebb6-4529-86f1-\
c4b21f17706f"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["sin", 
         RowBox[{"-", "1"}]], "(", 
        FractionBox["z", "2"], ")"}]}], ")"}], 
     RowBox[{"2", " ", "k"}]], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", " ", "k"}], ")"}], "!"}]], "\[LongEqual]", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "k"}], "\[Infinity]"], 
    FractionBox[
     RowBox[{
      SuperscriptBox["z", 
       RowBox[{"2", " ", "n"}]], " ", 
      RowBox[{"t0", "(", 
       RowBox[{"k", ",", "n"}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", "n"}], ")"}], "!"}]]}]}], 
  TraditionalForm]], "formattedWL",ExpressionUUID->"9da1e4ab-def4-465d-8ee3-\
6aad10b7644b"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"67f058cd-1aa0-4b66-ab71-e49b8bec96fd"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", " ", "k"}], ")"}], "!"}]}], " ", "*", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"ArcSin", "[", 
         RowBox[{"z", "/", "2"}], "]"}]}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"2", " ", "k"}], ")"}]}]}], " ", "==", " ", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"t0", "[", 
        RowBox[{"k", ",", " ", "n"}], "]"}], "*", 
       RowBox[{
        RowBox[{"z", "^", 
         RowBox[{"(", 
          RowBox[{"2", " ", "n"}], ")"}]}], "/", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", " ", "n"}], ")"}], "!"}]}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n", ",", " ", "k", ",", " ", "Infinity"}], "}"}]}], "]"}]}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"eb5246a8-3d78-4909-a0b3-\
d5782a717709"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "eq:gen-funct-cfn1",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"5e39e5a9-2bb7-4b7c-b11e-28ace3d40239"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"abf8e004-3a8d-4759-ab22-2671f77a7698"],

Cell["\<\

\\frac{1}{(2k+1)!} \
\\left[2\\;\\mathrm{arcsin}\\left(\\frac{z}{2}\\right)\\right]^{2k+1}
&=&\\sum_{n=k}^\\infty  t_1(k,n)  \\frac{z^{2n+1}}{(2n+1)!}, \\quad k\\geq0.
\
\>", "rawTeX",ExpressionUUID->"66c27dc1-b64d-4840-acd5-d036a0cb67c8"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"17aba49c-59be-4329-bd4e-dad7128d9420"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"3a954e72-0f93-491c-a117-b48afa02d87b"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"bf3d4ebb-bcfd-4c6e-a238-e1b65bb21bd5"],

Cell["\<\
Here, factorial and ArcSin are properly formatted in Wolfram Language, with \
the series expressed using Sum. The function t1[k, n] correctly represents \
the subscript notation in TeX.


```
## [TeXSectionID]Equations from TeX Source Code[/TeXSectionID]
```\
\>", "LLMComment",ExpressionUUID->"8060983d-11ea-4a3b-acdc-b8e1e3759561"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"1481c266-ee67-4e23-bec2-\
ec6a5f5d68a9"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["sin", 
         RowBox[{"-", "1"}]], "(", 
        FractionBox["z", "2"], ")"}]}], ")"}], 
     RowBox[{
      RowBox[{"2", " ", "k"}], "+", "1"}]], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "k"}], "+", "1"}], ")"}], "!"}]], "\[LongEqual]", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "k"}], "\[Infinity]"], 
    FractionBox[
     RowBox[{
      SuperscriptBox["z", 
       RowBox[{
        RowBox[{"2", " ", "n"}], "+", "1"}]], " ", 
      RowBox[{"t1", "(", 
       RowBox[{"k", ",", "n"}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "n"}], "+", "1"}], ")"}], "!"}]]}]}], 
  TraditionalForm]], "formattedWL",ExpressionUUID->"1bfc90f9-5e40-4d70-9a5e-\
a5c76b5e9213"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"af9c8530-0269-49da-ba77-3b0e2068c3d5"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "k"}], " ", "+", " ", "1"}], ")"}], "!"}]}], " ", 
     "*", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"ArcSin", "[", 
         RowBox[{"z", "/", "2"}], "]"}]}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "k"}], " ", "+", " ", "1"}], ")"}]}]}], " ", "==", 
    " ", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"t1", "[", 
        RowBox[{"k", ",", " ", "n"}], "]"}], "*", 
       RowBox[{
        RowBox[{"z", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "n"}], " ", "+", " ", "1"}], ")"}]}], "/", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "n"}], " ", "+", " ", "1"}], ")"}], "!"}]}]}], 
      ",", " ", 
      RowBox[{"{", 
       RowBox[{"n", ",", " ", "k", ",", " ", "Infinity"}], "}"}]}], "]"}]}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"7e5fb350-3dcd-4a3f-a3b6-\
2ef6cd446a4d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "eq:Tood_integral",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"1c7e57ce-36e2-4154-b5d9-7bfbd3450198"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"e1d4b710-48b5-41c2-b672-35d7454ca0a6"],

Cell["\<\

\\Hodd{k}{j} = \\sum_{l=0}^k \\frac{1}{(2l)!} \
\\left(\\frac{\\pi}{2}\\right)^{2l}
\\int_{C_{k-l}}
\\prod_{i=l+1}^k\\frac{   x_{i}^{2j} \\log(x_i) dx_i}
     {\\left(1- \\prod_{m=l+1}^i x_{m}^2\\right) }
\
\>", "rawTeX",ExpressionUUID->"64cb57fb-0147-4045-98d8-c4aa3927b7a8"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"33913e6e-c639-49e8-9e1a-de3ddd8be5ef"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"669f0d91-d947-4ecf-8e59-a70cf805014b"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"653c1d63-a3f7-4492-9368-dd47a34547c8"],

Cell["\<\
Converted the integral to Wolfram Language syntax, using Subscript for the \
indices and including correct bounds on integrals. The product over a range \
is directly translated to the Product function. The factorial and power \
expressions are directly translated as well.\
\>", "LLMComment",ExpressionUUID->"1688b4ad-f89f-4d08-a355-342f559bbc4c"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"b7fc341d-4480-4b8d-b2a8-\
c467cb9ba750"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["H", "1"], "(", 
    RowBox[{"k", ",", "j"}], ")"}], "\[LongEqual]", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"l", "=", "0"}], "k"], 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["\[Pi]", "2"], ")"}], 
       RowBox[{"2", " ", "l"}]], " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "1"], 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "1"], 
        RowBox[{
         FractionBox[
          RowBox[{
           UnderoverscriptBox["\[Product]", 
            RowBox[{"i", "=", 
             RowBox[{"l", "+", "1"}]}], "k"], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"x", "(", "i", ")"}], 
             RowBox[{"2", " ", "j"}]], " ", 
            RowBox[{"log", "(", 
             RowBox[{"x", "(", "i", ")"}], ")"}]}]}], 
          RowBox[{
           UnderoverscriptBox["\[Product]", 
            RowBox[{"i", "=", 
             RowBox[{"l", "+", "1"}]}], "k"], 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                UnderoverscriptBox["\[Product]", 
                 RowBox[{"m", "=", 
                  RowBox[{"l", "+", "1"}]}], "i"], 
                RowBox[{"x", "(", "m", ")"}]}], ")"}], "2"]}], ")"}]}]], 
         RowBox[{"\[DifferentialD]", 
          RowBox[{"x", "(", "k", ")"}]}], 
         RowBox[{"\[DifferentialD]", 
          RowBox[{"x", "(", 
           RowBox[{"l", "+", "1"}], ")"}]}]}]}]}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", "l"}], ")"}], "!"}]]}]}], 
  TraditionalForm]], "formattedWL",ExpressionUUID->"e0bacb7e-5304-4111-a421-\
4144f9654225"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"c090b2a4-4b55-4174-b1f3-d4721181ee8e"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Subscript", "[", 
      RowBox[{"H", ",", " ", "1"}], "]"}], "[", 
     RowBox[{"k", ",", " ", "j"}], "]"}], " ", "==", " ", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", " ", "l"}], ")"}], "!"}]}], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Pi", "/", "2"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"2", " ", "l"}], ")"}]}], " ", 
       RowBox[{"Integrate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Product", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"x", "[", "i", "]"}], "^", 
              RowBox[{"(", 
               RowBox[{"2", " ", "j"}], ")"}]}], " ", 
             RowBox[{"Log", "[", 
              RowBox[{"x", "[", "i", "]"}], "]"}]}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", 
              RowBox[{"l", " ", "+", " ", "1"}], ",", " ", "k"}], "}"}]}], 
           "]"}], "/", 
          RowBox[{"Product", "[", 
           RowBox[{
            RowBox[{"1", " ", "-", " ", 
             RowBox[{
              RowBox[{"Product", "[", 
               RowBox[{
                RowBox[{"x", "[", "m", "]"}], ",", " ", 
                RowBox[{"{", 
                 RowBox[{"m", ",", " ", 
                  RowBox[{"l", " ", "+", " ", "1"}], ",", " ", "i"}], "}"}]}],
                "]"}], "^", "2"}]}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", 
              RowBox[{"l", " ", "+", " ", "1"}], ",", " ", "k"}], "}"}]}], 
           "]"}]}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"x", "[", 
            RowBox[{"l", " ", "+", " ", "1"}], "]"}], ",", " ", "0", ",", " ",
            "1"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"x", "[", "k", "]"}], ",", " ", "0", ",", " ", "1"}], 
          "}"}]}], "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"l", ",", " ", "0", ",", " ", "k"}], "}"}]}], "]"}]}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"3e4e2ddc-18b7-4e98-9944-\
74176ac8e825"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "th:teve-integral",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"e7f7a92b-c86a-45e5-a1d2-9d68fc040f49"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"ffe9b93b-894c-4220-a72c-2c89d8464ab6"],

Cell["\<\

\\Heve{k+1}{j} = \\sum_{l=0}^k \\frac{\\pi^{2l}}{(2l+1)!}
\\int_{C_{k-l}}
 \\prod_{i=l+1}^k \\frac{  x_{i}^{j-1} \\log(x_i) dx_i}
     { \\left(1- \\prod_{m=l+1}^i x_{m}\\right) }   
\
\>", "rawTeX",ExpressionUUID->"0a23a5bd-d595-4e4c-935a-9411ce205103"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"3568e317-2333-4594-9a7f-3da467d728a7"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"b5c37d99-e13b-4f69-8912-57e30d57dfe1"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"9d4c66c7-bfd4-46a3-be50-baec413a6924"],

Cell["\<\
Transformed TeX integral notation into Wolfram Language, maintaining the \
structure of the products and divisions. The summation uses standard \
notation, and the factorial in the denominator is correctly translated. \
Variable subscripts and powers are handled appropriately.


```
## [TeXSectionID]Equation Conversion to Wolfram Language[/TeXSectionID]
```\
\>", "LLMComment",ExpressionUUID->"951fe505-8047-4b94-9976-3512daa516e4"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"69fc595b-1a51-49b5-9559-\
0590d343711b"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["H", "0"], "(", 
    RowBox[{
     RowBox[{"k", "+", "1"}], ",", "j"}], ")"}], "\[LongEqual]", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"l", "=", "0"}], "k"], 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[Pi]", 
       RowBox[{"2", " ", "l"}]], " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "1"], 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "1"], 
        RowBox[{
         FractionBox[
          RowBox[{
           UnderoverscriptBox["\[Product]", 
            RowBox[{"i", "=", 
             RowBox[{"l", "+", "1"}]}], "k"], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"x", "(", "i", ")"}], 
             RowBox[{"j", "-", "1"}]], " ", 
            RowBox[{"log", "(", 
             RowBox[{"x", "(", "i", ")"}], ")"}]}]}], 
          RowBox[{
           UnderoverscriptBox["\[Product]", 
            RowBox[{"i", "=", 
             RowBox[{"l", "+", "1"}]}], "k"], 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{
              UnderoverscriptBox["\[Product]", 
               RowBox[{"m", "=", 
                RowBox[{"l", "+", "1"}]}], "i"], 
              RowBox[{"x", "(", "m", ")"}]}]}], ")"}]}]], 
         RowBox[{"\[DifferentialD]", 
          RowBox[{"x", "(", "k", ")"}]}], 
         RowBox[{"\[DifferentialD]", 
          RowBox[{"x", "(", 
           RowBox[{"l", "+", "1"}], ")"}]}]}]}]}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "l"}], "+", "1"}], ")"}], "!"}]]}]}], 
  TraditionalForm]], "formattedWL",ExpressionUUID->"b0e8b98b-ab29-4252-9a97-\
1dc2970bee98"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"10a5eb70-9cb1-454d-9d79-5ff3ab83a383"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Subscript", "[", 
      RowBox[{"H", ",", " ", "0"}], "]"}], "[", 
     RowBox[{
      RowBox[{"k", " ", "+", " ", "1"}], ",", " ", "j"}], "]"}], " ", "==", 
    " ", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Pi", "^", 
          RowBox[{"(", 
           RowBox[{"2", " ", "l"}], ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "l"}], " ", "+", " ", "1"}], ")"}], "!"}], 
         ")"}]}], "*", 
       RowBox[{"Integrate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Product", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"x", "[", "i", "]"}], "^", 
              RowBox[{"(", 
               RowBox[{"j", " ", "-", " ", "1"}], ")"}]}], "*", 
             RowBox[{"Log", "[", 
              RowBox[{"x", "[", "i", "]"}], "]"}]}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", 
              RowBox[{"l", " ", "+", " ", "1"}], ",", " ", "k"}], "}"}]}], 
           "]"}], "/", 
          RowBox[{"Product", "[", 
           RowBox[{
            RowBox[{"1", " ", "-", " ", 
             RowBox[{"Product", "[", 
              RowBox[{
               RowBox[{"x", "[", "m", "]"}], ",", " ", 
               RowBox[{"{", 
                RowBox[{"m", ",", " ", 
                 RowBox[{"l", " ", "+", " ", "1"}], ",", " ", "i"}], "}"}]}], 
              "]"}]}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", 
              RowBox[{"l", " ", "+", " ", "1"}], ",", " ", "k"}], "}"}]}], 
           "]"}]}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"x", "[", 
            RowBox[{"l", " ", "+", " ", "1"}], "]"}], ",", " ", "0", ",", " ",
            "1"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"x", "[", "k", "]"}], ",", " ", "0", ",", " ", "1"}], 
          "}"}]}], "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"l", ",", " ", "0", ",", " ", "k"}], "}"}]}], "]"}]}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"a26dfb2c-9924-4814-8856-\
ac6f9b93d27d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "eq:rkk",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"c644a37e-6cf4-4205-baf3-e7fe9574553c"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"632afbb0-7ef1-4afb-b8cb-e55df9c2a23f"],

Cell["\<\

r_l^{(k)}(x_1,\\ldots x_k) = \\frac{ (-1)^{k+l} \\prod_{i=1}^{l} x_i^{2(i-1)} }
{\\prod_{i=1}^{l} \\left(1-\\prod_{m=i}^l x_m^2\\right) \\prod_{i=l+1}^{k} \
\\left(1- \\prod_{m=l+1}^i x_{m}^2\\right) },
\
\>", "rawTeX",ExpressionUUID->"1b378b0b-1948-4a5d-b19f-6175deae2beb"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"3304ed77-e39a-4b6d-b888-40d4f1db850f"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"cd422661-a3e3-4b9e-ab1d-f1b2fdb80499"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"6d55d083-579d-41a9-b315-66d5eb6cac97"],

Cell["\<\
Variables with subscripts converted to `Subscript` and indices are handled \
accordingly. The product function is translated to `Product`.\
\>", "LLMComment",ExpressionUUID->"f7b5f0a5-50fc-48c7-bdac-9ef44a0e9dad"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"9efd7b95-7200-4dd7-b438-\
045fb9d1811a"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["r", "l"], "(", "k", ")"}], "\[InvisibleApplication]", 
    RowBox[{"(", 
     RowBox[{"Sequence", "@@", 
      RowBox[{"Table", "[", 
       RowBox[{
        SubscriptBox["x", "i"], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "k"}], "}"}]}], "]"}]}], ")"}]}], 
   "\[LongEqual]", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], 
      RowBox[{"k", "+", "l"}]], " ", 
     RowBox[{
      UnderoverscriptBox["\[Product]", 
       RowBox[{"i", "=", "1"}], "l"], 
      SubsuperscriptBox["x", "i", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"i", "-", "1"}], ")"}]}]]}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       UnderoverscriptBox["\[Product]", 
        RowBox[{"i", "=", "1"}], "l"], 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          UnderoverscriptBox["\[Product]", 
           RowBox[{"m", "=", "i"}], "l"], 
          SubsuperscriptBox["x", "m", "2"]}]}], ")"}]}], ")"}], " ", 
     RowBox[{
      UnderoverscriptBox["\[Product]", 
       RowBox[{"i", "=", 
        RowBox[{"l", "+", "1"}]}], "k"], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         UnderoverscriptBox["\[Product]", 
          RowBox[{"m", "=", 
           RowBox[{"l", "+", "1"}]}], "i"], 
         SubsuperscriptBox["x", "m", "2"]}]}], ")"}]}]}]]}], 
  TraditionalForm]], "formattedWL",ExpressionUUID->"08d61b2d-0f2d-497d-ab2a-\
0547af6536d9"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"438abdfe-3ca5-4008-958c-b0143144f4b9"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Subscript", "[", 
       RowBox[{"r", ",", " ", "l"}], "]"}], "[", "k", "]"}], "[", 
     RowBox[{"Sequence", " ", "@@", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Subscript", "[", 
         RowBox[{"x", ",", " ", "i"}], "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", " ", "1", ",", " ", "k"}], "}"}]}], "]"}]}], "]"}],
     " ", "==", " ", "\n", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"k", " ", "+", " ", "l"}], ")"}]}], " ", 
     RowBox[{
      RowBox[{"Product", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"x", ",", " ", "i"}], "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"i", " ", "-", " ", "1"}], ")"}]}], ")"}]}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", " ", "1", ",", " ", "l"}], "}"}]}], "]"}], " ", 
      "/", "\n", "  ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Product", "[", 
         RowBox[{
          RowBox[{"1", " ", "-", " ", 
           RowBox[{"Product", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"x", ",", " ", "m"}], "]"}], "^", "2"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"m", ",", " ", "i", ",", " ", "l"}], "}"}]}], "]"}]}], 
          ",", " ", 
          RowBox[{"{", 
           RowBox[{"i", ",", " ", "1", ",", " ", "l"}], "}"}]}], "]"}], " ", 
        RowBox[{"Product", "[", 
         RowBox[{
          RowBox[{"1", " ", "-", " ", 
           RowBox[{"Product", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"x", ",", " ", "m"}], "]"}], "^", "2"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"m", ",", " ", 
               RowBox[{"l", " ", "+", " ", "1"}], ",", " ", "i"}], "}"}]}], 
            "]"}]}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"i", ",", " ", 
            RowBox[{"l", " ", "+", " ", "1"}], ",", " ", "k"}], "}"}]}], 
         "]"}]}], ")"}]}]}]}], "\n"}]}]], "linearizedWL",ExpressionUUID->\
"7a7de70d-2df6-4e92-b8c4-e7ef9b567850"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "r_l^{(k)}(x_1,\\ldots,x_k) related equation",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"b882febe-0089-4650-97ee-a95e0539fb22"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"1e26d4e4-5cfe-4d41-a85e-0aafdffb5743"],

Cell["\<\

r_l^{(k)}(x_1,\\ldots,x_k) =  r_l^{(k-1)}(x_1,\\ldots,x_{k-1}) \
\\frac{-1}{1-(x_{l+1}\\ldots x_k)^2}, \\quad\\mbox{if } 0\\leq l<k,
\
\>", "rawTeX",ExpressionUUID->"18d6d97b-669c-4317-aea3-0cc3e91f74ce"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"c0c596e4-f565-4f8c-981a-0d7472396095"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"bd9b9596-663b-4408-8dff-e0e29eaea844"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"60379663-7681-42b0-aaf3-0d5deb8ca2b0"],

Cell["\<\
Continuation of the product application with indices properly managed. Each \
variable is subscripted correctly and iterated over a product.\
\>", "LLMComment",ExpressionUUID->"75b38180-8cfd-406e-a70c-84e58b0dc774"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"3d9a3d78-0803-4b2e-9efc-\
03678fe570e6"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["r", "l"], "(", "k", ")"}], "\[InvisibleApplication]", 
    RowBox[{"(", 
     RowBox[{"Sequence", "@@", 
      RowBox[{"Table", "[", 
       RowBox[{
        SubscriptBox["x", "i"], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "k"}], "}"}]}], "]"}]}], ")"}]}], 
   "\[LongEqual]", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["r", "l"], "(", 
       RowBox[{"k", "-", "1"}], ")"}], "\[InvisibleApplication]", 
      RowBox[{"(", 
       RowBox[{"Sequence", "@@", 
        RowBox[{"Table", "[", 
         RowBox[{
          SubscriptBox["x", "i"], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"k", "-", "1"}]}], "}"}]}], "]"}]}], ")"}]}]}], 
    RowBox[{"1", "-", 
     RowBox[{
      UnderoverscriptBox["\[Product]", 
       RowBox[{"i", "=", 
        RowBox[{"l", "+", "1"}]}], "k"], 
      SubsuperscriptBox["x", "i", "2"]}]}]]}], 
  TraditionalForm]], "formattedWL",ExpressionUUID->"6805c283-9881-4820-8539-\
e748e39b512e"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"fc68aa08-8901-46cb-b0bb-a3ead370a9c1"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Subscript", "[", 
       RowBox[{"r", ",", " ", "l"}], "]"}], "[", "k", "]"}], "[", 
     RowBox[{"Sequence", " ", "@@", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Subscript", "[", 
         RowBox[{"x", ",", " ", "i"}], "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", " ", "1", ",", " ", "k"}], "}"}]}], "]"}]}], "]"}],
     " ", "==", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Subscript", "[", 
        RowBox[{"r", ",", " ", "l"}], "]"}], "[", 
       RowBox[{"k", " ", "-", " ", "1"}], "]"}], "[", 
      RowBox[{"Sequence", " ", "@@", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"x", ",", " ", "i"}], "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"i", ",", " ", "1", ",", " ", 
           RowBox[{"k", " ", "-", " ", "1"}]}], "}"}]}], "]"}]}], "]"}], "*", 
     
     RowBox[{
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", 
        RowBox[{"Product", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"x", ",", " ", "i"}], "]"}], "^", "2"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"i", ",", " ", 
            RowBox[{"l", " ", "+", " ", "1"}], ",", " ", "k"}], "}"}]}], 
         "]"}]}], ")"}]}]}]}], "\n"}]}]], "linearizedWL",ExpressionUUID->\
"fd126ba0-dcb2-4f10-8440-65b4dcae336b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "r_l^{(l)}(x_1,\\ldots,x_l)",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"13c234f8-3584-43ac-87df-5f0e3e6eae97"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"15ec20ef-1506-4eb0-8d42-9e9d14723822"],

Cell["\<\

r_l^{(l)}(x_1,\\ldots,x_l) = \\frac{ x_1^{0}x_2^2\\ldots x_l^{2l-2} } \
{(1-x_l^2)\\ldots(1-x_1^2\\ldots x_l^2) }    
\
\>", "rawTeX",ExpressionUUID->"39e02b9f-1199-4a1f-bbae-c49875fd7c8e"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"61309ae5-aaa0-4c71-8580-1790ec173bc0"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"7c273241-65b2-4033-8579-80bf5840d3e5"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"994e2a05-cdee-4618-b27d-52a113d1d1d9"],

Cell["\<\
The power and product functions are translated correctly to their \
corresponding Wolfram Language expressions. The iterative product terms are \
properly managed for each index.\
\>", "LLMComment",ExpressionUUID->"93b27fad-28ec-4c44-b3f9-6d23c0decb27"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"bd795add-12bf-446c-a2bb-\
4ceae985ae1e"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["r", "l"], "(", "l", ")"}], "\[InvisibleApplication]", 
    RowBox[{"(", 
     RowBox[{"Sequence", "@@", 
      RowBox[{"Table", "[", 
       RowBox[{
        SubscriptBox["x", "i"], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "l"}], "}"}]}], "]"}]}], ")"}]}], 
   "\[LongEqual]", 
   FractionBox[
    RowBox[{
     UnderoverscriptBox["\[Product]", 
      RowBox[{"i", "=", "1"}], "l"], 
     SubsuperscriptBox["x", "i", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"i", "-", "1"}], ")"}]}]]}], 
    RowBox[{
     UnderoverscriptBox["\[Product]", 
      RowBox[{"j", "=", "1"}], "l"], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        UnderoverscriptBox["\[Product]", 
         RowBox[{"i", "=", "1"}], "j"], 
        SubsuperscriptBox["x", "i", "2"]}]}], ")"}]}]]}], 
  TraditionalForm]], "formattedWL",ExpressionUUID->"c98fd389-f27b-4091-bf80-\
13b9681c2b95"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"a0afa225-d9df-4f42-8fc7-4440d9768095"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Subscript", "[", 
       RowBox[{"r", ",", " ", "l"}], "]"}], "[", "l", "]"}], "[", 
     RowBox[{"Sequence", " ", "@@", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Subscript", "[", 
         RowBox[{"x", ",", " ", "i"}], "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", " ", "1", ",", " ", "l"}], "}"}]}], "]"}]}], "]"}],
     " ", "==", " ", 
    RowBox[{
     RowBox[{"Product", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Subscript", "[", 
         RowBox[{"x", ",", " ", "i"}], "]"}], "^", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"i", " ", "-", " ", "1"}], ")"}]}], ")"}]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", "l"}], "}"}]}], "]"}], "/", 
     RowBox[{"Product", "[", 
      RowBox[{
       RowBox[{"1", " ", "-", " ", 
        RowBox[{"Product", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"x", ",", " ", "i"}], "]"}], "^", "2"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"i", ",", " ", "1", ",", " ", "j"}], "}"}]}], "]"}]}], ",",
        " ", 
       RowBox[{"{", 
        RowBox[{"j", ",", " ", "1", ",", " ", "l"}], "}"}]}], "]"}]}]}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"15f3a7d6-f9f2-4db8-b702-\
222efec6c822"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "\\Hodd{k}{j}",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"c381b705-66a5-4350-bda9-bf65bbcf7559"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"82dccd4d-e29d-4983-a0f5-c225d4653e14"],

Cell["\<\

\\Hodd{k}{j} = \\sum_{l=0}^k 
\\int_{C_l} \\prod_{i=1}^{l} (-1)^l \\frac{ x_i^{2(i-1)}  \\log(x_i) dx_i }
                                       { \\left(1-\\prod_{m=i}^l \
x_m^2\\right) }
\\times
\\int_{C_{k-l}} \\prod_{i=l+1}^k \\frac{  x_{i}^{2j} \\log(x_i) dx_i }
                                    {  \\left(1- \\prod_{m=l+1}^i \
x_{m}^2\\right) }
\
\>", "rawTeX",ExpressionUUID->"65b33d7a-2ac4-4a49-af3c-37d3f29e50e4"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"d8d50538-6663-486b-9501-c1e3d8704fbc"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"f1d88d18-2e9a-499a-8934-6ea39908e956"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"01bc9bd7-5ecc-4f77-b623-a96d854fd3ab"],

Cell["\<\
Complex nested integrals and summations are translated, ensuring accurate \
indices and proper handling of products and integrals. The formula for \
products inside integral expressions is particularly detailed and carefully \
converted.\
\>", "LLMComment",ExpressionUUID->"255bdca9-5f84-4f85-9ac1-d023164bb8e8"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"5a171ae9-8e28-4220-99d8-\
164a4538b65e"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["H", "1"], "(", 
    RowBox[{"k", ",", "j"}], ")"}], "\[LongEqual]", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"l", "=", "0"}], "k"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "1"], 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "1", "l"], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           UnderoverscriptBox["\[Product]", 
            RowBox[{"i", "=", "1"}], "l"], 
           FractionBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "l"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubsuperscriptBox["x", "i", 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{"i", "-", "1"}], ")"}]}]], " ", 
               RowBox[{"log", "(", 
                SubscriptBox["x", "i"], ")"}]}], ")"}]}], 
            RowBox[{"1", "-", 
             RowBox[{
              UnderoverscriptBox["\[Product]", 
               RowBox[{"m", "=", "i"}], "l"], 
              SubsuperscriptBox["x", "m", "2"]}]}]]}], ")"}], 
         RowBox[{"\[DifferentialD]", "i"}], 
         RowBox[{"\[DifferentialD]", 
          SubscriptBox["x", "i"]}]}]}]}], ")"}], " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       SubsuperscriptBox["\[Integral]", 
        RowBox[{"l", "+", "1"}], "k"], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          UnderoverscriptBox["\[Product]", 
           RowBox[{"i", "=", 
            RowBox[{"l", "+", "1"}]}], "k"], 
          FractionBox[
           RowBox[{
            SubsuperscriptBox["x", "i", 
             RowBox[{"2", " ", "j"}]], " ", 
            RowBox[{"log", "(", 
             SubscriptBox["x", "i"], ")"}]}], 
           RowBox[{"1", "-", 
            RowBox[{
             UnderoverscriptBox["\[Product]", 
              RowBox[{"m", "=", 
               RowBox[{"l", "+", "1"}]}], "i"], 
             SubsuperscriptBox["x", "m", "2"]}]}]]}], ")"}], 
        RowBox[{"\[DifferentialD]", "i"}], 
        RowBox[{"\[DifferentialD]", 
         SubscriptBox["x", "i"]}]}]}]}]}]}]}], 
  TraditionalForm]], "formattedWL",ExpressionUUID->"fe3ca6f3-2b54-47b3-8c9f-\
f0d1b8c79522"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"27a924c9-c693-474d-b110-93dcc011c949"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Subscript", "[", 
      RowBox[{"H", ",", " ", "1"}], "]"}], "[", 
     RowBox[{"k", ",", " ", "j"}], "]"}], " ", "==", " ", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Integrate", "[", 
        RowBox[{
         RowBox[{"Product", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "^", "l"}], " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"x", ",", " ", "i"}], "]"}], "^", 
                RowBox[{"(", 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{"i", " ", "-", " ", "1"}], ")"}]}], ")"}]}], " ", 
               RowBox[{"Log", "[", 
                RowBox[{"Subscript", "[", 
                 RowBox[{"x", ",", " ", "i"}], "]"}], "]"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"1", " ", "-", " ", 
               RowBox[{"Product", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Subscript", "[", 
                   RowBox[{"x", ",", " ", "m"}], "]"}], "^", "2"}], ",", " ", 
                 
                 RowBox[{"{", 
                  RowBox[{"m", ",", " ", "i", ",", " ", "l"}], "}"}]}], 
                "]"}]}], ")"}]}]}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"i", ",", " ", "1", ",", " ", "l"}], "}"}]}], "]"}], ",", 
         " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"x", ",", " ", "i"}], "]"}], ",", " ", "0", ",", " ", 
           "1"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"i", ",", " ", "1", ",", " ", "l"}], "}"}]}], "]"}], "*", 
       "\n", "  ", 
       RowBox[{"Integrate", "[", 
        RowBox[{
         RowBox[{"Product", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Subscript", "[", 
                RowBox[{"x", ",", " ", "i"}], "]"}], "^", 
               RowBox[{"(", 
                RowBox[{"2", " ", "j"}], ")"}]}], " ", 
              RowBox[{"Log", "[", 
               RowBox[{"Subscript", "[", 
                RowBox[{"x", ",", " ", "i"}], "]"}], "]"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"1", " ", "-", " ", 
              RowBox[{"Product", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"Subscript", "[", 
                  RowBox[{"x", ",", " ", "m"}], "]"}], "^", "2"}], ",", " ", 
                RowBox[{"{", 
                 RowBox[{"m", ",", " ", 
                  RowBox[{"l", " ", "+", " ", "1"}], ",", " ", "i"}], "}"}]}],
                "]"}]}], ")"}]}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"i", ",", " ", 
             RowBox[{"l", " ", "+", " ", "1"}], ",", " ", "k"}], "}"}]}], 
          "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"x", ",", " ", "i"}], "]"}], ",", " ", "0", ",", " ", 
           "1"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"i", ",", " ", 
           RowBox[{"l", " ", "+", " ", "1"}], ",", " ", "k"}], "}"}]}], 
        "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"l", ",", " ", "0", ",", " ", "k"}], "}"}]}], "]"}]}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"0d9fd925-98fc-4a48-a6c5-\
bde101f5ec84"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Proof of the main results", "Subsection",
 Editable->True,
 ShowAutoSpellCheck->
  False,ExpressionUUID->"9ef3c4d2-70c2-4202-bee7-7e5d555849e0"],

Cell[CellGroupData[{

Cell[TextData[{
 "eq:moment-series-cot",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"aefc1fcc-582a-4d1a-9dab-0b29af878a34"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"c2519120-75ec-4ca3-8d0f-9bf48af1a440"],

Cell["\<\

C(m) = \\sum_{n=m}^{\\infty} |t(n,m)| \\frac{2^n}{n\\ n!}
\
\>", "rawTeX",ExpressionUUID->"b0292cec-b259-4afa-b49d-593a01a751e0"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"37efff32-9996-456f-b686-8d4efe01435b"],

Cell["(not available)", "renderedTeX",ExpressionUUID->"46af489c-bf9c-46d2-a917-5a405274cd84"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"28b4d295-ad98-4590-b1ab-995b9e9df5ba"],

Cell["\<\
The TeX symbol |t(n,m)|, which denotes the absolute value of t(n, m), is \
converted to Absolute[t[n, m]] in Wolfram Language. The sum from n = m to \
infinity is represented using Sum.\
\>", "LLMComment",ExpressionUUID->"ed778df7-ac9e-419a-bba1-481704353f59"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"2749b5fe-8c69-4964-8888-\
a22d25c781c0"],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"m_"},
    "CTraditional"], ":=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "m"}], "\[Infinity]"], 
    FractionBox[
     RowBox[{
      SuperscriptBox["2", "n"], " ", 
      RowBox[{"Absolute", "[", 
       RowBox[{"t", "(", 
        RowBox[{"n", ",", "m"}], ")"}], "]"}]}], 
     RowBox[{"n", " ", 
      RowBox[{"n", "!"}]}]]}]}], TraditionalForm]], "formattedWL",ExpressionUU\
ID->"7bff41b7-5848-49ef-be87-14b69d9896d8"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"7a3e112f-de53-4421-9c78-8a7e86128087"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"C", "[", "m_", "]"}], " ", ":=", " ", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Absolute", "[", 
        RowBox[{"t", "[", 
         RowBox[{"n", ",", " ", "m"}], "]"}], "]"}], " ", 
       RowBox[{
        RowBox[{"2", "^", "n"}], "/", 
        RowBox[{"(", 
         RowBox[{"n", " ", 
          RowBox[{"n", "!"}]}], ")"}]}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"n", ",", " ", "m", ",", " ", "Infinity"}], "}"}]}], "]"}]}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"41841e98-ecc4-4530-b698-\
9270511ffc92"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "eq:Codd-Ceve",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"e6941164-0356-4312-9be6-71a5f65ac2ce"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"cae88792-c1ef-45a8-99d5-11f6ce4f082b"],

Cell["\<\

\\begin{eqnarray*}
\\Codd{k} &=& 2^{2k+1}
\\sum_{j=0}^\\infty \\binom{2j}{j}   \\frac{1}{4^{j}} \
\\frac{\\Hodd{k}{j}}{(2j+1)^2} \\\\
\\Ceve{k} &=&  \\frac{1}{2} \\sum_{j=1}^\\infty \
\\frac{2^{2j}}{j^3\\binom{2j}{j}} \\Heve{k}{j}.
\\end{eqnarray*}
\
\>", "rawTeX",ExpressionUUID->"3773ebfe-4f45-4903-abc1-aea4e727724d"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"b8d88ab4-1425-4462-b5cd-cba9830d43dd"],

Cell[TextData[{
 Cell["", "Text",ExpressionUUID->"a1db40d1-592f-4dd1-8086-c5b7519285b2"],
 Cell[BoxData[
  FormBox[Cell[BoxData[
    FormBox[GridBox[{
       {Cell[TextData[Cell[BoxData[
         FormBox[
          StyleBox["k", "TI"], TraditionalForm]],ExpressionUUID->
         "f993fc3d-c5f2-4a01-a215-8066b39c21de"]],ExpressionUUID->
         "311dfdfa-86ca-48ff-92f8-664a981558a9"], Cell[TextData[Cell[BoxData[
         FormBox[
          StyleBox["\[LongEqual]", "DisplayFormula"], TraditionalForm]],
         ExpressionUUID->"6ce8a006-66fb-49f1-a3ea-d9233f6462a1"]],
         ExpressionUUID->"f74dc431-11d1-480c-ae1a-bb200364bc18"], Cell[
        TextData[Cell[BoxData[
         FormBox[
          StyleBox[
           RowBox[{
            SuperscriptBox["2", 
             RowBox[{"2", 
              StyleBox["k", "TI"], "+", "1"}]], 
            RowBox[{
             UnderoverscriptBox["\[Sum]", 
              RowBox[{
               StyleBox["j", "TI"], "\[LongEqual]", "0"}], "\[Infinity]",
              LimitsPositioning->True], 
             RowBox[{
              TemplateBox[{
                RowBox[{"2", 
                  StyleBox["j", "TI"]}], 
                StyleBox["j", "TI"]},
               "Binomial"], 
              FractionBox["1", 
               SuperscriptBox["4", 
                StyleBox["j", "TI"]]], 
              FractionBox[
               StyleBox[
                RowBox[{"k", "j"}], "TI"], 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"2", 
                  StyleBox["j", "TI"], "+", "1"}], ")"}], "2"]]}]}]}], 
           "DisplayFormula"], TraditionalForm]],ExpressionUUID->
         "9ef7cc71-9573-4b1c-8517-ae985f0c0c12"]],ExpressionUUID->
         "09c2c4b3-d90a-4360-abb9-8e2246beb372"]},
       {Cell[TextData[Cell[BoxData[
         FormBox[
          StyleBox["k", "TI"], TraditionalForm]],ExpressionUUID->
         "e6594808-cdbd-4560-bc23-9081e9221167"]],ExpressionUUID->
         "94c24dc7-0812-4ee6-8e48-a9e13a756d8f"], Cell[TextData[Cell[BoxData[
         FormBox[
          StyleBox["\[LongEqual]", "DisplayFormula"], TraditionalForm]],
         ExpressionUUID->"858c48f1-9d7d-4a22-bdc9-7746ca99071b"]],
         ExpressionUUID->"4912d739-8b50-44ff-89b5-83148af9ab6b"], Cell[
        TextData[Cell[BoxData[
         FormBox[
          StyleBox[
           RowBox[{
            FractionBox["1", "2"], 
            RowBox[{
             UnderoverscriptBox["\[Sum]", 
              RowBox[{
               StyleBox["j", "TI"], "\[LongEqual]", "1"}], "\[Infinity]",
              LimitsPositioning->True], 
             RowBox[{
              FractionBox[
               SuperscriptBox["2", 
                RowBox[{"2", 
                 StyleBox["j", "TI"]}]], 
               RowBox[{
                SuperscriptBox[
                 StyleBox["j", "TI"], "3"], 
                TemplateBox[{
                  RowBox[{"2", 
                    StyleBox["j", "TI"]}], 
                  StyleBox["j", "TI"]},
                 "Binomial"]}]], 
              StyleBox["k", "TI"], 
              RowBox[{
               StyleBox["j", "TI"], "."}]}]}]}], "DisplayFormula"], 
          TraditionalForm]],ExpressionUUID->
         "58581ac4-7740-4595-a4a5-cf1c85e9ec39"]],ExpressionUUID->
         "0fdd66a4-32d0-4b55-b3f7-23d322a796d0"]}
      },
      GridBoxAlignment->{
       "Columns" -> {Right, Center, {Left}}, "Rows" -> {{Baseline}}}], 
     TraditionalForm]],ExpressionUUID->
    "d5a89874-06bf-47b0-944a-dea46db09b41"], TraditionalForm]], 
  "NumberedEquation",ExpressionUUID->"fd6aecba-5fe4-48e5-98e0-6facf2fe0877"]
}], "renderedTeX",ExpressionUUID->"39b0e326-1abb-4a8c-a857-fdd695b32e13"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"b7808628-2829-44b7-bdb6-e5969d431657"],

Cell["\<\
Transformed the TeX binomial notation \\binom{2j}{j} to Wolfram's \
Binomial[2j, j]. The series are correctly represented using Sum in Wolfram \
Language. The functions Codd and Ceven represent the odd and even series \
respectively.\
\>", "LLMComment",ExpressionUUID->"404b7451-d387-445d-a24a-d1e35d26d5b0"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"b47c1c4d-7320-44d6-846c-\
d0ba51975d40"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Codd", "(", "k_", ")"}], ":=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["2", 
      RowBox[{
       RowBox[{"2", " ", "k"}], "+", "1"}]], " ", 
     RowBox[{"Ceven", "(", "k_", ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"j", "=", "0"}], "\[Infinity]"], 
       FractionBox[
        RowBox[{
         TemplateBox[{
           RowBox[{"2", " ", "j"}], "j"},
          "Binomial"], " ", 
         RowBox[{"Hodd", "(", 
          RowBox[{"k", ",", "j"}], ")"}]}], 
        RowBox[{
         SuperscriptBox["4", "j"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "j"}], "+", "1"}], ")"}], "2"]}]]}], ")"}]}], ":=", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"j", "=", "1"}], "\[Infinity]"], 
      FractionBox[
       RowBox[{
        SuperscriptBox["2", 
         RowBox[{"2", " ", "j"}]], " ", 
        RowBox[{"Heven", "(", 
         RowBox[{"k", ",", "j"}], ")"}]}], 
       RowBox[{
        SuperscriptBox["j", "3"], " ", 
        TemplateBox[{
          RowBox[{"2", " ", "j"}], "j"},
         "Binomial"]}]]}]}]}]}], TraditionalForm]], "formattedWL",ExpressionUU\
ID->"5ab111ff-8e31-40be-8193-92c91ed374fb"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"8104ff36-7689-4954-977b-1f1820324e02"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"Codd", "[", "k_", "]"}], " ", ":=", " ", 
    RowBox[{
     RowBox[{"2", "^", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "k"}], " ", "+", " ", "1"}], ")"}]}], " ", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Binomial", "[", 
          RowBox[{
           RowBox[{"2", " ", "j"}], ",", " ", "j"}], "]"}], "/", 
         RowBox[{"4", "^", "j"}]}], " ", 
        RowBox[{
         RowBox[{"Hodd", "[", 
          RowBox[{"k", ",", " ", "j"}], "]"}], "/", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "j"}], " ", "+", " ", "1"}], ")"}], "^", 
          "2"}]}]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"j", ",", " ", "0", ",", " ", "Infinity"}], "}"}]}], 
      "]"}]}]}], "\n", 
   RowBox[{
    RowBox[{"Ceven", "[", "k_", "]"}], " ", ":=", " ", 
    RowBox[{
     RowBox[{"1", "/", "2"}], " ", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"2", "^", 
          RowBox[{"(", 
           RowBox[{"2", " ", "j"}], ")"}]}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"j", "^", "3"}], " ", 
           RowBox[{"Binomial", "[", 
            RowBox[{
             RowBox[{"2", " ", "j"}], ",", " ", "j"}], "]"}]}], ")"}]}], " ", 
        
        RowBox[{"Heven", "[", 
         RowBox[{"k", ",", " ", "j"}], "]"}]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"j", ",", " ", "1", ",", " ", "Infinity"}], "}"}]}], 
      "]"}]}]}], "\n"}]}]], "linearizedWL",ExpressionUUID->"df8b6e8c-0557-\
49a1-b273-f7f2c419f41d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "eq:Codd-Ceve-integral",
 " ",
 StyleBox["(equation label)", "eqLabel"]
}], "Subsubsection",ExpressionUUID->"8d35f020-757f-4c35-937e-c3d1c1eec368"],

Cell["Raw TeX", "arXivLabel", "label-rawTeX",ExpressionUUID->"9f479ab5-d4da-4289-ac4a-6dc793782077"],

Cell["\<\

\\begin{eqnarray*}
\\Codd{k} &=& 2^{2k+1} \\sum_{l=0}^k \
\\frac{1}{(2l)!}\\left(\\frac{\\pi}{2}\\right)^{2l}
\\int_{C_{k-l}}  K_1(x_1\\ldots x_{k-l})
\\prod_{i=1}^{k-l} \\frac{\\log(x_i)dx_i}{1-\\prod_{m=1}^i x_m^2}\\\\
\\Ceve{k} &=& \\sum_{l=0}^k \\frac{\\pi^{2l}}{(2l+1)!}
\\int_{C_{k-l}}  K_0(x_1 \\ldots x_{k-l})
\\prod_{i=1}^{k-l} \\frac{\\log(x_i)dx_i}{1-\\prod_{m=1}^i x_m }.
\\end{eqnarray*}
\
\>", "rawTeX",ExpressionUUID->"f4b38c87-4fd1-405d-9b3d-6e5e1f2352ba"],

Cell["Rendered TeX (approximated by WL)", "label-renderedTeX",ExpressionUUID->"ef096b53-4fcb-4df1-b89b-3ad894c92319"],

Cell[TextData[{
 Cell["", "Text",ExpressionUUID->"f676d21d-f663-4542-b63b-2e1b95e61264"],
 Cell[BoxData[
  FormBox[Cell[BoxData[
    FormBox[GridBox[{
       {Cell[TextData[Cell[BoxData[
         FormBox[
          StyleBox["k", "TI"], TraditionalForm]],ExpressionUUID->
         "d4789b1d-12b9-43a6-b17c-764b94e1ce17"]],ExpressionUUID->
         "43b849cf-8030-42e0-bc41-dd76b35c2b62"], Cell[TextData[Cell[BoxData[
         FormBox[
          StyleBox["\[LongEqual]", "DisplayFormula"], TraditionalForm]],
         ExpressionUUID->"9b77a560-6328-4848-8675-222e0d5a6ba3"]],
         ExpressionUUID->"c79a3bdf-f861-4a36-bd48-4efdeb75bfd6"], Cell[
        TextData[Cell[BoxData[
         FormBox[
          StyleBox[
           RowBox[{
            SuperscriptBox["2", 
             RowBox[{"2", 
              StyleBox["k", "TI"], "+", "1"}]], 
            UnderoverscriptBox["\[Sum]", 
             RowBox[{
              StyleBox["l", "TI"], "\[LongEqual]", "0"}], 
             StyleBox["k", "TI"],
             LimitsPositioning->True], 
            FractionBox["1", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", 
                StyleBox["l", "TI"]}], ")"}], "!"}]], 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox["\[Pi]", "2"], ")"}], 
             RowBox[{"2", 
              StyleBox["l", "TI"]}]], 
            SubscriptBox["\[Integral]", 
             SubscriptBox[
              StyleBox["C", "TI"], 
              RowBox[{
               StyleBox["k", "TI"], "-", 
               StyleBox["l", "TI"]}]]], 
            SubscriptBox[
             StyleBox["K", "TI"], "1"], 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox[
               StyleBox["x", "TI"], "1"], "\[Ellipsis]", 
              SubscriptBox[
               StyleBox["x", "TI"], 
               RowBox[{
                StyleBox["k", "TI"], "-", 
                StyleBox["l", "TI"]}]]}], ")"}], 
            UnderoverscriptBox["\[Product]", 
             RowBox[{
              StyleBox["i", "TI"], "\[LongEqual]", "1"}], 
             RowBox[{
              StyleBox["k", "TI"], "-", 
              StyleBox["l", "TI"]}],
             LimitsPositioning->True], 
            FractionBox[
             RowBox[{"log", 
              RowBox[{"(", 
               SubscriptBox[
                StyleBox["x", "TI"], 
                StyleBox["i", "TI"]], ")"}], 
              StyleBox["d", "TI"], 
              SubscriptBox[
               StyleBox["x", "TI"], 
               StyleBox["i", "TI"]]}], 
             RowBox[{"1", "-", 
              UnderoverscriptBox["\[Product]", 
               RowBox[{
                StyleBox["m", "TI"], "\[LongEqual]", "1"}], 
               StyleBox["i", "TI"],
               LimitsPositioning->True], 
              SubsuperscriptBox[
               StyleBox["x", "TI"], 
               StyleBox["m", "TI"], "2"]}]]}], "DisplayFormula"], 
          TraditionalForm]],ExpressionUUID->
         "4a1377f5-c763-4bb9-9af9-207b5ae967bd"]],ExpressionUUID->
         "ca52e0bb-6d75-42f0-a2d6-bf29053983fb"]},
       {Cell[TextData[Cell[BoxData[
         FormBox[
          StyleBox["k", "TI"], TraditionalForm]],ExpressionUUID->
         "107e2f77-a748-4fa7-9a34-dc84602d8e22"]],ExpressionUUID->
         "3fb87d62-58bd-4540-a86c-46819d1f62a5"], Cell[TextData[Cell[BoxData[
         FormBox[
          StyleBox["\[LongEqual]", "DisplayFormula"], TraditionalForm]],
         ExpressionUUID->"fb69c82d-f329-4f5b-a920-e4201e59f3af"]],
         ExpressionUUID->"fb1f3323-1a94-4c11-9a94-3955db285a7a"], Cell[
        TextData[Cell[BoxData[
         FormBox[
          StyleBox[
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{
              StyleBox["l", "TI"], "\[LongEqual]", "0"}], 
             StyleBox["k", "TI"],
             LimitsPositioning->True], 
            FractionBox[
             SuperscriptBox["\[Pi]", 
              RowBox[{"2", 
               StyleBox["l", "TI"]}]], 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", 
                StyleBox["l", "TI"], "+", "1"}], ")"}], "!"}]], 
            SubscriptBox["\[Integral]", 
             SubscriptBox[
              StyleBox["C", "TI"], 
              RowBox[{
               StyleBox["k", "TI"], "-", 
               StyleBox["l", "TI"]}]]], 
            SubscriptBox[
             StyleBox["K", "TI"], "0"], 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox[
               StyleBox["x", "TI"], "1"], "\[Ellipsis]", 
              SubscriptBox[
               StyleBox["x", "TI"], 
               RowBox[{
                StyleBox["k", "TI"], "-", 
                StyleBox["l", "TI"]}]]}], ")"}], 
            UnderoverscriptBox["\[Product]", 
             RowBox[{
              StyleBox["i", "TI"], "\[LongEqual]", "1"}], 
             RowBox[{
              StyleBox["k", "TI"], "-", 
              StyleBox["l", "TI"]}],
             LimitsPositioning->True], 
            FractionBox[
             RowBox[{"log", 
              RowBox[{"(", 
               SubscriptBox[
                StyleBox["x", "TI"], 
                StyleBox["i", "TI"]], ")"}], 
              StyleBox["d", "TI"], 
              SubscriptBox[
               StyleBox["x", "TI"], 
               StyleBox["i", "TI"]]}], 
             RowBox[{"1", "-", 
              UnderoverscriptBox["\[Product]", 
               RowBox[{
                StyleBox["m", "TI"], "\[LongEqual]", "1"}], 
               StyleBox["i", "TI"],
               LimitsPositioning->True], 
              SubscriptBox[
               StyleBox["x", "TI"], 
               StyleBox["m", "TI"]]}]], "."}], "DisplayFormula"], 
          TraditionalForm]],ExpressionUUID->
         "95dbc6fe-d095-41e8-8a99-a11b36c86359"]],ExpressionUUID->
         "1e889d82-0727-47e3-9b43-2d65caedfc18"]}
      },
      GridBoxAlignment->{
       "Columns" -> {Right, Center, {Left}}, "Rows" -> {{Baseline}}}], 
     TraditionalForm]],ExpressionUUID->
    "dd3bd02f-b009-42da-abf8-997ca5f6378d"], TraditionalForm]], 
  "NumberedEquation",ExpressionUUID->"85cd2516-e370-4483-b8ad-256a72b1dbd0"]
}], "renderedTeX",ExpressionUUID->"b8a34d01-ef47-4494-8793-06ccb59c9e1e"],

Cell["LLM conversion comment (generated by LLM)", "label-llmComment",ExpressionUUID->"8106a7d2-ac53-4c81-ad3f-cecee7fab68d"],

Cell["\<\
The multiple integrals are converted by defining the range for each variable \
x[i] from 0 to 1 and using Integrate in Wolfram Language. The products inside \
the integrals are handled using Product. The function Sequence @@ Table is \
used to dynamically generate function arguments for K1 and K0 based on the \
iterating variable l.\
\>", "LLMComment",ExpressionUUID->"2a452af6-6494-45ca-a223-5f6ff9bb8b3f"],

Cell["\<\
Formatted Wolfram Language code (generated by LLM and formatted by WL)\
\>", "label-formattedWL",ExpressionUUID->"d3cc8eaa-78c2-49b9-b299-\
f41216ee948e"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Codd", "(", "k_", ")"}], ":=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["2", 
      RowBox[{
       RowBox[{"2", " ", "k"}], "+", "1"}]], " ", 
     RowBox[{"Ceven", "(", "k_", ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"l", "=", "0"}], "k"], 
       RowBox[{
        FractionBox["1", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", " ", "l"}], ")"}], "!"}]], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["\[Pi]", "2"], ")"}], 
          RowBox[{"2", " ", "l"}]], " ", 
         RowBox[{"\[Integral]", 
          RowBox[{
           RowBox[{
            RowBox[{
             UnderoverscriptBox["\[Product]", 
              RowBox[{"i", "=", "1"}], 
              RowBox[{"k", "-", "l"}]], 
             FractionBox[
              RowBox[{"log", "(", 
               RowBox[{"x", "(", "i", ")"}], ")"}], 
              RowBox[{
               UnderoverscriptBox["\[Product]", 
                RowBox[{"i", "=", "1"}], 
                RowBox[{"k", "-", "l"}]], 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    UnderoverscriptBox["\[Product]", 
                    RowBox[{"m", "=", "1"}], "i"], 
                    RowBox[{"x", "(", "m", ")"}]}], ")"}], "2"]}], ")"}]}]]}],
             " ", 
            RowBox[{"K1", "(", 
             RowBox[{"Sequence", "@@", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"x", "(", "i", ")"}], ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "1", ",", 
                  RowBox[{"k", "-", "l"}]}], "}"}]}], "]"}]}], ")"}]}], 
           RowBox[{"\[DifferentialD]", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"Sequence", "@@", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"x", "(", "i", ")"}], ",", "0", ",", "1"}], "}"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "1", ",", 
                  RowBox[{"k", "-", "l"}]}], "}"}]}], "]"}]}], 
             "]"}]}]}]}]}]}]}], ")"}]}], ":=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"l", "=", "0"}], "k"], 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "l"}], "+", "1"}], ")"}], "!"}]], 
      RowBox[{
       SuperscriptBox["\[Pi]", 
        RowBox[{"2", " ", "l"}]], " ", 
       RowBox[{"\[Integral]", 
        RowBox[{
         RowBox[{
          RowBox[{
           UnderoverscriptBox["\[Product]", 
            RowBox[{"i", "=", "1"}], 
            RowBox[{"k", "-", "l"}]], 
           FractionBox[
            RowBox[{"log", "(", 
             RowBox[{"x", "(", "i", ")"}], ")"}], 
            RowBox[{
             UnderoverscriptBox["\[Product]", 
              RowBox[{"i", "=", "1"}], 
              RowBox[{"k", "-", "l"}]], 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{
                UnderoverscriptBox["\[Product]", 
                 RowBox[{"m", "=", "1"}], "i"], 
                RowBox[{"x", "(", "m", ")"}]}]}], ")"}]}]]}], " ", 
          RowBox[{"K0", "(", 
           RowBox[{"Sequence", "@@", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"x", "(", "i", ")"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "1", ",", 
                RowBox[{"k", "-", "l"}]}], "}"}]}], "]"}]}], ")"}]}], 
         RowBox[{"\[DifferentialD]", 
          RowBox[{"Evaluate", "[", 
           RowBox[{"Sequence", "@@", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x", "(", "i", ")"}], ",", "0", ",", "1"}], "}"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "1", ",", 
                RowBox[{"k", "-", "l"}]}], "}"}]}], "]"}]}], 
           "]"}]}]}]}]}]}]}]}]}], TraditionalForm]], "formattedWL",ExpressionU\
UID->"43437700-4b0b-493c-af60-05a8b0189f43"],

Cell["Raw Wolfram Language code (generated by LLM)", "label-linearizedWL",ExpressionUUID->"58ab4e50-7897-485c-880d-81da2246d751"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"Codd", "[", "k_", "]"}], " ", ":=", " ", 
    RowBox[{
     RowBox[{"2", "^", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "k"}], " ", "+", " ", "1"}], ")"}]}], " ", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"Factorial", "[", 
          RowBox[{"2", " ", "l"}], "]"}]}], " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Pi", "/", "2"}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"2", " ", "l"}], ")"}]}], " ", "\n", "           ", 
        RowBox[{"Integrate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"K1", "[", 
            RowBox[{"Sequence", " ", "@@", " ", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"x", "[", "i", "]"}], ",", " ", 
               RowBox[{"{", 
                RowBox[{"i", ",", " ", "1", ",", " ", 
                 RowBox[{"k", " ", "-", " ", "l"}]}], "}"}]}], "]"}]}], "]"}],
            " ", "\n", "           ", 
           RowBox[{"Product", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Log", "[", 
               RowBox[{"x", "[", "i", "]"}], "]"}], "/", 
              RowBox[{"Product", "[", 
               RowBox[{
                RowBox[{"1", " ", "-", " ", 
                 RowBox[{
                  RowBox[{"Product", "[", 
                   RowBox[{
                    RowBox[{"x", "[", "m", "]"}], ",", " ", 
                    RowBox[{"{", 
                    RowBox[{"m", ",", " ", "1", ",", " ", "i"}], "}"}]}], 
                   "]"}], "^", "2"}]}], ",", " ", 
                RowBox[{"{", 
                 RowBox[{"i", ",", " ", "1", ",", " ", 
                  RowBox[{"k", " ", "-", " ", "l"}]}], "}"}]}], "]"}]}], ",", 
             " ", 
             RowBox[{"{", 
              RowBox[{"i", ",", " ", "1", ",", " ", 
               RowBox[{"k", " ", "-", " ", "l"}]}], "}"}]}], "]"}]}], ",", 
          " ", "\n", "           ", 
          RowBox[{"Evaluate", "[", 
           RowBox[{"Sequence", " ", "@@", " ", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x", "[", "i", "]"}], ",", " ", "0", ",", " ", "1"}], 
               "}"}], ",", " ", 
              RowBox[{"{", 
               RowBox[{"i", ",", " ", "1", ",", " ", 
                RowBox[{"k", " ", "-", " ", "l"}]}], "}"}]}], "]"}]}], 
           "]"}]}], "]"}]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"l", ",", " ", "0", ",", " ", "k"}], "}"}]}], "]"}]}]}], "\n", 
   RowBox[{
    RowBox[{"Ceven", "[", "k_", "]"}], " ", ":=", " ", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Pi", "^", 
         RowBox[{"(", 
          RowBox[{"2", " ", "l"}], ")"}]}], "/", 
        RowBox[{"Factorial", "[", 
         RowBox[{
          RowBox[{"2", " ", "l"}], " ", "+", " ", "1"}], "]"}]}], " ", "\n", 
       "           ", 
       RowBox[{"Integrate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"K0", "[", 
           RowBox[{"Sequence", " ", "@@", " ", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"x", "[", "i", "]"}], ",", " ", 
              RowBox[{"{", 
               RowBox[{"i", ",", " ", "1", ",", " ", 
                RowBox[{"k", " ", "-", " ", "l"}]}], "}"}]}], "]"}]}], "]"}], 
          " ", "\n", "           ", 
          RowBox[{"Product", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Log", "[", 
              RowBox[{"x", "[", "i", "]"}], "]"}], "/", 
             RowBox[{"Product", "[", 
              RowBox[{
               RowBox[{"1", " ", "-", " ", 
                RowBox[{"Product", "[", 
                 RowBox[{
                  RowBox[{"x", "[", "m", "]"}], ",", " ", 
                  RowBox[{"{", 
                   RowBox[{"m", ",", " ", "1", ",", " ", "i"}], "}"}]}], 
                 "]"}]}], ",", " ", 
               RowBox[{"{", 
                RowBox[{"i", ",", " ", "1", ",", " ", 
                 RowBox[{"k", " ", "-", " ", "l"}]}], "}"}]}], "]"}]}], ",", 
            " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", " ", "1", ",", " ", 
              RowBox[{"k", " ", "-", " ", "l"}]}], "}"}]}], "]"}]}], ",", " ",
          "\n", "           ", 
         RowBox[{"Evaluate", "[", 
          RowBox[{"Sequence", " ", "@@", " ", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"x", "[", "i", "]"}], ",", " ", "0", ",", " ", "1"}], 
              "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"i", ",", " ", "1", ",", " ", 
               RowBox[{"k", " ", "-", " ", "l"}]}], "}"}]}], "]"}]}], "]"}]}],
         "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"l", ",", " ", "0", ",", " ", "k"}], "}"}]}], "]"}]}], 
   "\n"}]}]], "linearizedWL",ExpressionUUID->"a17730c8-a0a2-493c-a37c-\
3cc20ef518a2"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 807},
WindowMargins->{{364, Automatic}, {Automatic, 50}},
FrontEndVersion->"14.1 for Mac OS X x86 (64-bit) (July 16, 2024)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Chapter"], ShowCellBracket -> False, 
    CellMargins -> {{68, 3.}, {0., 35.}}, FontSize -> 28, FontColor -> 
    Hue[0.55, 0.88, 0.65]], 
   Cell[
    StyleData["Title"], ShowCellBracket -> False, 
    CellMargins -> {{67, 30.}, {10., 30.}}, LineSpacing -> {0.95, 2}, 
    FontColor -> GrayLevel[0.25]], 
   Cell[
    StyleData["Section"], Editable -> False, CellFrame -> {{0, 0}, {0, 2}}, 
    CellMargins -> {{68, 3.}, {0, 38.}}, 
    CellFrameMargins -> {{0, 0}, {0, 10}}, CellFrameColor -> GrayLevel[0.7], 
    ShowAutoSpellCheck -> False, FontSize -> 36, FontColor -> 
    Hue[0.55, 0.88, 0.65]], 
   Cell[
    StyleData["Subsection"], Editable -> False, 
    CellMargins -> {{68, 3.}, {0., 30.}}, ShowAutoSpellCheck -> False, 
    FontSize -> 26, FontColor -> Hue[0.55, 0.68, 0.75]], 
   Cell[
    StyleData["Subsubsection"], CellFrame -> {{0, 0}, {0, 1}}, 
    CellMargins -> {{68, 10.}, {10., 20.}}, 
    CellFrameMargins -> {{0, 0}, {0, 10}}, CellFrameColor -> GrayLevel[0.7], 
    ShowAutoSpellCheck -> False, IgnoreSpellCheck -> True, FontSize -> 22, 
    FontColor -> GrayLevel[0.3]], 
   Cell[
    StyleData["eqLabel", StyleDefinitions -> StyleData["Text"]], FontSize -> 
    16, FontSlant -> "Italic", FontColor -> GrayLevel[0.5]], 
   Cell[
    StyleData["arXivLabel", StyleDefinitions -> StyleData["Text"]], Editable -> 
    True, CellFrame -> {{4, 0}, {0, 0}}, CellMargins -> {{68, 10}, {0, 10}}, 
    CellFrameMargins -> {{10, 10}, {5, 5}}, 
    CellChangeTimes -> {3.9223576281937532`*^9}, ShowAutoSpellCheck -> False, 
    FontSize -> 14, FontSlant -> "Italic", FontColor -> GrayLevel[0.4], 
    Background -> GrayLevel[0.95]], 
   Cell[
    StyleData[
    "label-renderedTeX", StyleDefinitions -> StyleData["arXivLabel"]], 
    CellFrameColor -> RGBColor[0., 0.567, 0.845]], 
   Cell[
    StyleData["label-rawTeX", StyleDefinitions -> StyleData["arXivLabel"]], 
    CellFrameColor -> RGBColor[0.256, 0.675, 0.641]], 
   Cell[
    StyleData[
    "label-llmComment", StyleDefinitions -> StyleData["arXivLabel"]], 
    CellFrameColor -> GrayLevel[0.55]], 
   Cell[
    StyleData[
    "label-formattedWL", StyleDefinitions -> StyleData["arXivLabel"]], 
    CellFrameColor -> RGBColor[0.913, 0.421, 0.039]], 
   Cell[
    StyleData[
    "label-linearizedWL", StyleDefinitions -> StyleData["arXivLabel"]], 
    CellFrameColor -> RGBColor[0.794, 0.065, 0.077]], 
   Cell[
    StyleData["renderedTeX", StyleDefinitions -> StyleData["Text"]], Editable -> 
    True, CellFrame -> {{4, 0.00001}, {0.00001, 0.00001}}, 
    CellMargins -> {{68, 0.}, {0., 0}}, 
    CellFrameMargins -> {{10, 10.}, {5., 5.}}, CellFrameColor -> 
    RGBColor[0., 0.567, 0.845], ShowAutoSpellCheck -> False, FontSize -> 18, 
    Background -> GrayLevel[0.985]], 
   Cell[
    StyleData["rawTeX", StyleDefinitions -> StyleData["Text"]], Editable -> 
    True, CellFrame -> {{4, 0.00001}, {0.00001, 0.00001}}, 
    CellMargins -> {{68, 0.}, {0., 0}}, 
    CellFrameMargins -> {{10, 10.}, {8., 8.}}, CellFrameColor -> 
    RGBColor[0.256, 0.675, 0.641], ShowAutoSpellCheck -> False, FontFamily -> 
    "Courier", FontSize -> 13.5, Background -> GrayLevel[0.985]], 
   Cell[
    StyleData["LLMComment", StyleDefinitions -> StyleData["Text"]], Editable -> 
    True, PageWidth -> 820, CellFrame -> {{4, 0.00001}, {0.00001, 0.00001}}, 
    CellMargins -> {{68, 0.}, {0., 0}}, 
    CellFrameMargins -> {{10, 10.}, {8., 8.}}, CellFrameColor -> 
    GrayLevel[0.55], ShowAutoSpellCheck -> False, Background -> 
    GrayLevel[0.985]], 
   Cell[
    StyleData["Input2"], CellMargins -> {{66, 10}, {5, 8}}, 
    StyleKeyMapping -> {
     "=" -> "WolframAlphaShort", "*" -> "Item", ">" -> 
      "ExternalLanguageDefault"}, Evaluatable -> True, CellGroupingRules -> 
    "InputGrouping", TextClipboardType -> "InputText", StripStyleOnPaste -> 
    True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
    DefaultFormatType -> DefaultInputFormatType, ContextMenu -> 
    FEPrivate`FrontEndResource["ContextMenus", "Input"], ShowAutoStyles -> 
    True, ShowAutoConvert -> True, 
    TranslationOptions -> {"ContentEnabled" -> Automatic}, 
    HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"}, 
    AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
    PasteAutoQuoteCharacters -> {}, LanguageCategory -> "Input", FormatType -> 
    InputForm, NumberMarks -> True, 
    LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, CounterIncrements -> "Input",
     MenuSortingValue -> 1500, MenuCommandKey :> "9", FontSize -> 14, 
    FontWeight -> "DemiBold"], 
   Cell[
    StyleData["formattedWL", StyleDefinitions -> StyleData["Input2"]], 
    Editable -> True, PageWidth -> 820, 
    CellFrame -> {{4, 0.00001}, {0.00001, 0.00001}}, 
    CellMargins -> {{68, 10.}, {0., 0}}, 
    CellFrameMargins -> {{10, 10.}, {8., 8.}}, CellFrameColor -> 
    RGBColor[0.913, 0.421, 0.039], Background -> GrayLevel[0.985]], 
   Cell[
    StyleData["linearizedWL", StyleDefinitions -> StyleData["Input2"]], 
    Editable -> True, PageWidth -> 820, 
    CellFrame -> {{4, 0.00001}, {0.00001, 0.00001}}, 
    CellMargins -> {{68, 10.}, {20., 0}}, 
    CellFrameMargins -> {{10, 10.}, {8., 8.}}, CellFrameColor -> 
    RGBColor[0.794, 0.065, 0.077], Background -> GrayLevel[0.985]], 
   Cell[
    StyleData["Hyperlink", StyleDefinitions -> StyleData["Link"]], FontColor -> 
    Hue[0.55, 0.88, 0.65]], 
   Cell[
    StyleData["metadata", StyleDefinitions -> StyleData["Text"]], 
    ShowCellBracket -> False, CellMargins -> {{66, 10}, {0, 0}}, 
    CellFrameMargins -> {{10, 4}, {4, 4}}, ShowAutoSpellCheck -> False, 
    FontSize -> 13, Background -> Hue[0.55, 0.05, 0.965]], 
   Cell[
    StyleData["metadataLabel", StyleDefinitions -> StyleData["metadata"]], 
    FontSlant -> "Italic", FontColor -> GrayLevel[0.4]]}, Visible -> False, 
  FrontEndVersion -> "14.1 for Mac OS X x86 (64-bit) (July 16, 2024)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"],
ExpressionUUID->"b22a632e-eb7d-493a-b225-1e4f054aaba8"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[554, 20, 174, 3, 70, "Chapter",ExpressionUUID->"18a7f091-052c-4791-8874-96debaa08d49"],
Cell[CellGroupData[{
Cell[753, 27, 249, 6, 237, "Title",ExpressionUUID->"3b9db973-5707-42b2-bf00-2b91c8f768e8"],
Cell[1005, 35, 2376, 73, 36, "Text",ExpressionUUID->"0020919c-39bc-413a-bf0f-c1bd8c9a07a9"],
Cell[CellGroupData[{
Cell[3406, 112, 137, 3, 62, "Subsection",ExpressionUUID->"3b6cf309-18e6-4339-8ea7-b8f5b68aac24"],
Cell[CellGroupData[{
Cell[3568, 119, 160, 4, 68, "Subsubsection",ExpressionUUID->"1bc2f818-af5b-408e-a6b8-5eb92fd266d2"],
Cell[3731, 125, 100, 0, 37, "arXivLabel",ExpressionUUID->"b69f0414-b52f-44e6-9353-1d041dd5d7a5"],
Cell[3834, 127, 217, 6, 95, "rawTeX",ExpressionUUID->"3577d4ba-a678-4709-882a-06b1b8c0e1ca"],
Cell[4054, 135, 117, 0, 37, "label-renderedTeX",ExpressionUUID->"fafc8a39-822a-4a47-a0a8-9d7d8c81949c"],
Cell[4174, 137, 93, 0, 32, "renderedTeX",ExpressionUUID->"a69d0d75-0946-4a68-94d6-df96c670799c"],
Cell[4270, 139, 124, 0, 37, "label-llmComment",ExpressionUUID->"f344b4ad-235a-43bc-8336-646d21e67138"],
Cell[4397, 141, 453, 6, 78, "LLMComment",ExpressionUUID->"96af5f49-908d-4a88-96c7-c59d6f9e8dc3"],
Cell[4853, 149, 164, 3, 37, "label-formattedWL",ExpressionUUID->"1cbf56df-a8e2-4eb5-8666-d7e12246db17"],
Cell[5020, 154, 509, 15, 58, "formattedWL",ExpressionUUID->"89e748ec-2584-45ce-8d2c-0ea26bf1a3f8"],
Cell[5532, 171, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"bbfb9149-da7d-4539-9c55-d4c2c54bbec6"],
Cell[5664, 173, 687, 20, 70, "linearizedWL",ExpressionUUID->"1e2396d8-b8c7-460f-b5f5-13da11976268"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6388, 198, 155, 4, 70, "Subsubsection",ExpressionUUID->"624dd037-3830-46bf-95f1-4f039400a514"],
Cell[6546, 204, 100, 0, 70, "arXivLabel",ExpressionUUID->"7d0766cb-ad27-4451-9ba0-0d7b2a8844ca"],
Cell[6649, 206, 291, 7, 70, "rawTeX",ExpressionUUID->"ad8bfabd-8a4b-401a-a159-798dc9654ba9"],
Cell[6943, 215, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"14028d40-b306-4af2-a494-6b131f58f7ef"],
Cell[7063, 217, 93, 0, 70, "renderedTeX",ExpressionUUID->"4e86228e-ddac-41c6-9b52-5e580ba71038"],
Cell[7159, 219, 124, 0, 70, "label-llmComment",ExpressionUUID->"b45c23f5-845c-4292-97e8-8f498122ffb2"],
Cell[7286, 221, 495, 7, 70, "LLMComment",ExpressionUUID->"71ab8558-ac6e-4906-8416-39a2adba5f12"],
Cell[7784, 230, 164, 3, 70, "label-formattedWL",ExpressionUUID->"7ae78e2a-a561-4dea-9768-57f1154334ab"],
Cell[7951, 235, 1206, 43, 70, "formattedWL",ExpressionUUID->"71600cba-7311-4a7c-9f0a-e6397b878639"],
Cell[9160, 280, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"2db4f1de-f2a3-438f-b473-46f7985196f4"],
Cell[9292, 282, 1517, 46, 70, "linearizedWL",ExpressionUUID->"21f7e8d2-5604-478a-8c2f-ca505b83ae00"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10846, 333, 164, 4, 70, "Subsubsection",ExpressionUUID->"2564e784-320f-4840-aa39-ec0ba6178f22"],
Cell[11013, 339, 100, 0, 70, "arXivLabel",ExpressionUUID->"d50e94aa-3fec-4986-a503-8e412c0de629"],
Cell[11116, 341, 157, 4, 70, "rawTeX",ExpressionUUID->"69aa5834-2095-4b38-b169-45d5efde406b"],
Cell[11276, 347, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"10897700-913e-4d22-b1fa-729703199022"],
Cell[11396, 349, 93, 0, 70, "renderedTeX",ExpressionUUID->"46adde41-5d83-4f54-958a-9f3758edbc4f"],
Cell[11492, 351, 124, 0, 70, "label-llmComment",ExpressionUUID->"583e7ec3-e937-465c-a3df-cacbae2b7a33"],
Cell[11619, 353, 375, 5, 70, "LLMComment",ExpressionUUID->"08fcda97-4fec-4d90-824b-f774392419e1"],
Cell[11997, 360, 164, 3, 70, "label-formattedWL",ExpressionUUID->"9ff461d4-a7db-446d-ac6a-030ea44f192a"],
Cell[12164, 365, 675, 22, 70, "formattedWL",ExpressionUUID->"2ada1730-803b-4505-b2af-6ff0bff175a3"],
Cell[12842, 389, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"e80d3416-5884-4eb3-9dc2-e14b4dba2390"],
Cell[12974, 391, 789, 25, 70, "linearizedWL",ExpressionUUID->"ef647190-f0f0-4049-a3df-5df782b46fbd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13800, 421, 168, 4, 70, "Subsubsection",ExpressionUUID->"3473c4c4-d885-4c8a-b913-f70a526bca4f"],
Cell[13971, 427, 100, 0, 70, "arXivLabel",ExpressionUUID->"1a1dd26f-dbaf-4434-a7dc-76e72eda5a13"],
Cell[14074, 429, 466, 11, 70, "rawTeX",ExpressionUUID->"dbc963a1-8f07-44fd-83b2-4e8c4eb3b29f"],
Cell[14543, 442, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"4a640960-e5dd-4f5b-b828-ead6d4a54086"],
Cell[14663, 444, 93, 0, 70, "renderedTeX",ExpressionUUID->"fa32cb65-b3ef-42cc-9b49-2779658d5e24"],
Cell[14759, 446, 124, 0, 70, "label-llmComment",ExpressionUUID->"63d0b51b-4493-4cd4-a43c-6c16b48a22a4"],
Cell[14886, 448, 596, 13, 70, "LLMComment",ExpressionUUID->"b08c3633-319a-44fa-9bff-8864005f00a6"],
Cell[15485, 463, 164, 3, 70, "label-formattedWL",ExpressionUUID->"f5bc7dc9-2cae-48db-8141-586ac93eaf6a"],
Cell[15652, 468, 157, 3, 70, "formattedWL",ExpressionUUID->"e9d4191f-ae83-4a3f-83c6-6e8bb59104c7"],
Cell[15812, 473, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"35c9a308-ee52-4b68-90e1-edf3832ee744"],
Cell[15944, 475, 4000, 106, 70, "linearizedWL",ExpressionUUID->"f814aec9-aaaa-4be3-b0b3-3afef1b68a4f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19981, 586, 155, 4, 70, "Subsubsection",ExpressionUUID->"fa94404a-40e5-4200-9738-a57df9058ca9"],
Cell[20139, 592, 100, 0, 70, "arXivLabel",ExpressionUUID->"c9011fb3-cb9b-4d21-9d86-48c4b4f33ba0"],
Cell[20242, 594, 274, 8, 70, "rawTeX",ExpressionUUID->"e83eea6f-712c-4efd-847a-592e99269f48"],
Cell[20519, 604, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"e16ffa5a-6da8-446d-8f28-426294224a8a"],
Cell[20639, 606, 93, 0, 70, "renderedTeX",ExpressionUUID->"575dba3a-9126-4fe5-9221-d97ee48b542b"],
Cell[20735, 608, 124, 0, 70, "label-llmComment",ExpressionUUID->"7e38bcaf-1c7c-4af1-a3bb-3badcb62d8eb"],
Cell[20862, 610, 273, 4, 70, "LLMComment",ExpressionUUID->"52d69cf3-94d5-4433-b10e-903ddaec7e41"],
Cell[21138, 616, 164, 3, 70, "label-formattedWL",ExpressionUUID->"7d098b69-c63e-46c8-b2b5-a909597f149d"],
Cell[21305, 621, 1375, 46, 70, "formattedWL",ExpressionUUID->"b7833408-ed8a-45d7-aa43-78961929a399"],
Cell[22683, 669, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"3952b6a4-ece4-4896-a4a8-891fb4b6e9d0"],
Cell[22815, 671, 1875, 55, 70, "linearizedWL",ExpressionUUID->"df17c705-443b-4914-99f5-3639878ae5a7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24727, 731, 199, 4, 70, "Subsubsection",ExpressionUUID->"b27182bc-09e5-4d08-9509-4f87a329f9f3"],
Cell[24929, 737, 100, 0, 70, "arXivLabel",ExpressionUUID->"e1f420fc-c0f2-45aa-b363-fdfe7d137d47"],
Cell[25032, 739, 550, 13, 70, "rawTeX",ExpressionUUID->"8719633c-a305-4b7d-9e1d-336950dc607a"],
Cell[25585, 754, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"1354402e-38d8-4da7-831c-4af2abf693e6"],
Cell[25705, 756, 93, 0, 70, "renderedTeX",ExpressionUUID->"f667526e-cc5d-4e4d-8afe-3576b2a418cc"],
Cell[25801, 758, 124, 0, 70, "label-llmComment",ExpressionUUID->"59c69bde-18ff-4db8-9075-c37134f93fbb"],
Cell[25928, 760, 248, 4, 70, "LLMComment",ExpressionUUID->"5d8460cf-1a39-4e5d-9bad-10bf6dd29f1c"],
Cell[26179, 766, 164, 3, 70, "label-formattedWL",ExpressionUUID->"204d7aec-fc44-48e0-aa60-b0a9a929c28d"],
Cell[26346, 771, 2136, 66, 70, "formattedWL",ExpressionUUID->"140dc3fe-38ee-4a1d-b75f-1d91fc42999e"],
Cell[28485, 839, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"5f9a4167-8ee5-4e27-9a04-c6cf2921e3d5"],
Cell[28617, 841, 2696, 78, 70, "linearizedWL",ExpressionUUID->"f2d60143-1894-448c-a998-b213894b0e14"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31350, 924, 230, 5, 70, "Subsubsection",ExpressionUUID->"563f929d-fdf1-40bf-a84c-beb668ec1584"],
Cell[31583, 931, 100, 0, 70, "arXivLabel",ExpressionUUID->"b89eb930-b3f1-43d8-a595-65e10976a32a"],
Cell[31686, 933, 260, 7, 70, "rawTeX",ExpressionUUID->"d757e206-40e6-4458-b9e2-16d52d628294"],
Cell[31949, 942, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"b656108f-eb57-4499-bfe5-8125a61004cb"],
Cell[32069, 944, 93, 0, 70, "renderedTeX",ExpressionUUID->"c671ac0c-b5ac-42aa-8db1-383df0e64d11"],
Cell[32165, 946, 124, 0, 70, "label-llmComment",ExpressionUUID->"7d7d383d-753b-4e57-9950-e7cd778a1063"],
Cell[32292, 948, 227, 3, 70, "LLMComment",ExpressionUUID->"3fa20791-52c5-4b8f-a656-733ab239ba17"],
Cell[32522, 953, 164, 3, 70, "label-formattedWL",ExpressionUUID->"1a401644-ba41-4fcb-ba76-d3c6fb1dee06"],
Cell[32689, 958, 996, 33, 70, "formattedWL",ExpressionUUID->"3242ad52-a5a0-4b38-b21d-930afeb6386a"],
Cell[33688, 993, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"1abc6595-2bb3-41d0-81b0-aab465c7a8e7"],
Cell[33820, 995, 1246, 39, 70, "linearizedWL",ExpressionUUID->"c5d1fbba-07d2-444f-8a03-f08b1db6dad9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35103, 1039, 174, 4, 70, "Subsubsection",ExpressionUUID->"6acd5a34-336e-42ae-b6c2-ef558f68ec20"],
Cell[35280, 1045, 100, 0, 70, "arXivLabel",ExpressionUUID->"77f28df1-fd06-4f74-b77f-1acea106415d"],
Cell[35383, 1047, 271, 7, 70, "rawTeX",ExpressionUUID->"90846dbf-b085-478e-9edd-e1af4d466d45"],
Cell[35657, 1056, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"d95d4864-8e15-452f-9f24-096611bf4a2e"],
Cell[35777, 1058, 93, 0, 70, "renderedTeX",ExpressionUUID->"7b155fb7-d327-4d43-942b-53e115e4e6f8"],
Cell[35873, 1060, 124, 0, 70, "label-llmComment",ExpressionUUID->"a1207e5b-1e9d-47bd-86c0-f22528898bfb"],
Cell[36000, 1062, 268, 4, 70, "LLMComment",ExpressionUUID->"1e7a82ab-c7da-4fa3-b5a1-239e0d9fc19f"],
Cell[36271, 1068, 164, 3, 70, "label-formattedWL",ExpressionUUID->"604a69c2-8663-4bc4-9c06-8ea155c40974"],
Cell[36438, 1073, 1060, 35, 70, "formattedWL",ExpressionUUID->"6aef41c6-a4bf-48e4-b7ba-1bab9830a7a0"],
Cell[37501, 1110, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"fe7c161b-7f0c-478b-8074-6865b40f51cc"],
Cell[37633, 1112, 1341, 42, 70, "linearizedWL",ExpressionUUID->"2b4e282a-9fd6-452d-b86c-00e960d8ce22"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[39023, 1160, 185, 4, 70, "Subsection",ExpressionUUID->"8ea3cef9-1b32-495d-aec9-c04d43f39bb7"],
Cell[CellGroupData[{
Cell[39233, 1168, 149, 4, 70, "Subsubsection",ExpressionUUID->"8d96287d-f0fa-45f7-abb7-bc7c8b3c4545"],
Cell[39385, 1174, 100, 0, 70, "arXivLabel",ExpressionUUID->"256fd4e9-e627-4a7e-87fa-c51ac1942774"],
Cell[39488, 1176, 253, 6, 70, "rawTeX",ExpressionUUID->"37ca19c2-938f-467a-b5f9-c5c3028119a6"],
Cell[39744, 1184, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"e6e12699-f07c-4c92-a5bd-7521ed8f0324"],
Cell[39864, 1186, 93, 0, 70, "renderedTeX",ExpressionUUID->"0c9fef55-f535-45cd-8a7f-8af228f97c42"],
Cell[39960, 1188, 124, 0, 70, "label-llmComment",ExpressionUUID->"f41a1957-ee05-4cfb-b979-425867c465d6"],
Cell[40087, 1190, 250, 4, 70, "LLMComment",ExpressionUUID->"b4fbd6e0-8436-44ab-95da-ab11be4f9294"],
Cell[40340, 1196, 164, 3, 70, "label-formattedWL",ExpressionUUID->"5de7782a-760c-4558-b09f-6336345842d0"],
Cell[40507, 1201, 938, 30, 70, "formattedWL",ExpressionUUID->"2ff8b419-7d5c-49b8-8bc5-1faf2e239390"],
Cell[41448, 1233, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"fa9548a6-8cfb-43ce-aa2e-5d63ca4f6f2d"],
Cell[41580, 1235, 1517, 43, 70, "linearizedWL",ExpressionUUID->"de929e4f-1b95-4e92-9a66-a067fc50fded"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43134, 1283, 149, 4, 70, "Subsubsection",ExpressionUUID->"657f6c41-8d4e-4027-b7b1-1c54b73c9652"],
Cell[43286, 1289, 100, 0, 70, "arXivLabel",ExpressionUUID->"63f0283e-c159-474f-9fa4-654404428877"],
Cell[43389, 1291, 238, 6, 70, "rawTeX",ExpressionUUID->"506b6ff8-ebc3-4f33-87da-74909bb023b3"],
Cell[43630, 1299, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"c215c14f-62b2-4619-9fa3-9f2d187a2521"],
Cell[43750, 1301, 93, 0, 70, "renderedTeX",ExpressionUUID->"0e55782e-f61d-4905-b22c-c1949f53af4a"],
Cell[43846, 1303, 124, 0, 70, "label-llmComment",ExpressionUUID->"4f4953d3-52e2-47a0-97ea-fa671660ffdc"],
Cell[43973, 1305, 220, 3, 70, "LLMComment",ExpressionUUID->"f55b7d14-2cb9-4806-9fb6-cd41b5e9212e"],
Cell[44196, 1310, 164, 3, 70, "label-formattedWL",ExpressionUUID->"e17989f8-40af-4a57-8be6-9dd407b847e7"],
Cell[44363, 1315, 734, 22, 70, "formattedWL",ExpressionUUID->"9e415ce7-a10a-4c27-877b-f347d86d3037"],
Cell[45100, 1339, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"b1dfa43f-e274-4f6d-a64b-21b9f4865093"],
Cell[45232, 1341, 1267, 35, 70, "linearizedWL",ExpressionUUID->"9e5edf23-d93d-4375-bfd4-24f60ddcab35"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46536, 1381, 163, 4, 70, "Subsubsection",ExpressionUUID->"78d14493-7379-4cb2-a83d-a8b9a9d0eae8"],
Cell[46702, 1387, 100, 0, 70, "arXivLabel",ExpressionUUID->"88b3cb7c-a079-495d-9c2c-0e0b7adfe28c"],
Cell[46805, 1389, 310, 8, 70, "rawTeX",ExpressionUUID->"e79abc68-c95e-464b-8624-e12d92544f82"],
Cell[47118, 1399, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"707d5670-d272-40b7-a9cc-b050f837c93f"],
Cell[47238, 1401, 93, 0, 70, "renderedTeX",ExpressionUUID->"31c869cc-6b5d-462a-8d61-7a04891973ec"],
Cell[47334, 1403, 124, 0, 70, "label-llmComment",ExpressionUUID->"74358896-9dac-47df-b494-a9a035267b21"],
Cell[47461, 1405, 303, 7, 70, "LLMComment",ExpressionUUID->"7a3ac895-be4f-49c0-9c9f-658d822635b2"],
Cell[47767, 1414, 164, 3, 70, "label-formattedWL",ExpressionUUID->"7983ece7-776f-458d-9fef-7ec31284fc44"],
Cell[47934, 1419, 1652, 57, 70, "formattedWL",ExpressionUUID->"bdf03714-b235-4e7d-ab2e-2e4cbe4a691c"],
Cell[49589, 1478, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"228493c0-9151-4d97-bd5b-7c923e56e04a"],
Cell[49721, 1480, 2200, 72, 70, "linearizedWL",ExpressionUUID->"52f63d41-c25d-4876-bdaa-d5484a5de35a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51958, 1557, 174, 4, 70, "Subsubsection",ExpressionUUID->"23b70ca8-48bf-4ec6-a8dc-bd55bbdef620"],
Cell[52135, 1563, 100, 0, 70, "arXivLabel",ExpressionUUID->"9e7d0c04-8c21-4a3f-80eb-33304bc32f33"],
Cell[52238, 1565, 156, 4, 70, "rawTeX",ExpressionUUID->"55bc079c-cd65-4839-afb6-22a3d5ff8ef7"],
Cell[52397, 1571, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"4edbf2b6-d8f7-444c-ba0f-6c0284e684f7"],
Cell[52517, 1573, 93, 0, 70, "renderedTeX",ExpressionUUID->"29acd5b2-c775-4be5-b4e4-f0e299ef6879"],
Cell[52613, 1575, 124, 0, 70, "label-llmComment",ExpressionUUID->"1f04bbeb-8dec-4ec2-be54-986fd714153a"],
Cell[52740, 1577, 213, 3, 70, "LLMComment",ExpressionUUID->"5fce4d9b-d44e-4592-9794-b07791aae9b1"],
Cell[52956, 1582, 164, 3, 70, "label-formattedWL",ExpressionUUID->"666b57bc-bdd4-4594-8e10-b8269eebdc66"],
Cell[53123, 1587, 793, 26, 70, "formattedWL",ExpressionUUID->"d4192bed-e1cb-449f-baed-9f086e36e8d3"],
Cell[53919, 1615, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"3aef0a9f-2a70-4e8f-9759-9a359417658b"],
Cell[54051, 1617, 984, 30, 70, "linearizedWL",ExpressionUUID->"fd5702a6-4e0d-4497-b27f-4b59c7678bfa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55072, 1652, 174, 4, 70, "Subsubsection",ExpressionUUID->"9d06fb17-b921-42f4-8f9d-80ef156cb489"],
Cell[55249, 1658, 100, 0, 70, "arXivLabel",ExpressionUUID->"7c138cab-5292-4bf5-82c8-e8e17ae55b79"],
Cell[55352, 1660, 162, 4, 70, "rawTeX",ExpressionUUID->"65446f7c-2fb3-4e9b-a9c7-8df72c6721cb"],
Cell[55517, 1666, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"88ff4f25-40dc-40e2-97e9-d960c284a9b0"],
Cell[55637, 1668, 93, 0, 70, "renderedTeX",ExpressionUUID->"8fd66ce4-a0b7-4a6f-b008-8e473d015748"],
Cell[55733, 1670, 124, 0, 70, "label-llmComment",ExpressionUUID->"b1cd8602-f27a-4bd6-8562-c0449a20aac7"],
Cell[55860, 1672, 172, 3, 70, "LLMComment",ExpressionUUID->"1d0bc61a-47ef-438a-89c0-38fa5dc1c68a"],
Cell[56035, 1677, 164, 3, 70, "label-formattedWL",ExpressionUUID->"616181cc-dfb0-4eba-a438-7c97548d7406"],
Cell[56202, 1682, 522, 16, 70, "formattedWL",ExpressionUUID->"b77efc0f-a1d8-4c3f-99ea-6d440dc2d41f"],
Cell[56727, 1700, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"8fc32ef4-4430-4e35-8dd7-47fb3212df6b"],
Cell[56859, 1702, 494, 15, 70, "linearizedWL",ExpressionUUID->"444c1011-ec01-4c3c-8639-493b6186bf46"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57390, 1722, 174, 4, 70, "Subsubsection",ExpressionUUID->"4007c9de-d078-42ba-8a48-39d18edf8f93"],
Cell[57567, 1728, 100, 0, 70, "arXivLabel",ExpressionUUID->"a7ec9b7e-efe3-4d14-81e4-a8b84e69728d"],
Cell[57670, 1730, 194, 5, 70, "rawTeX",ExpressionUUID->"ec90d983-0d2f-4940-b445-c05bd2cdb90a"],
Cell[57867, 1737, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"8eaa6b83-cc65-4287-a2a3-92aec4eacddd"],
Cell[57987, 1739, 93, 0, 70, "renderedTeX",ExpressionUUID->"54a9cbc3-73f5-4f2f-83ec-bb39648b7e98"],
Cell[58083, 1741, 124, 0, 70, "label-llmComment",ExpressionUUID->"f8ec84ee-4f99-49f7-9f17-3e48126981f4"],
Cell[58210, 1743, 171, 3, 70, "LLMComment",ExpressionUUID->"b9f1ae18-75a8-4fde-a808-f0db36c01b82"],
Cell[58384, 1748, 164, 3, 70, "label-formattedWL",ExpressionUUID->"ecd857fa-b509-48b4-8a60-af5f39d8d32c"],
Cell[58551, 1753, 539, 17, 70, "formattedWL",ExpressionUUID->"0aa4eb2d-260b-4d80-a55e-f43af62a785f"],
Cell[59093, 1772, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"e2687f79-9fd1-4a9c-80e5-552281e52d64"],
Cell[59225, 1774, 588, 17, 70, "linearizedWL",ExpressionUUID->"c0e31539-2366-47d3-9ab1-6a511b4aba58"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59850, 1796, 174, 4, 70, "Subsubsection",ExpressionUUID->"4cd1b13f-c533-4667-97aa-2bf8f331d980"],
Cell[60027, 1802, 100, 0, 70, "arXivLabel",ExpressionUUID->"5cd8a6d7-6bc4-4557-91a6-49a66cc7ed32"],
Cell[60130, 1804, 144, 4, 70, "rawTeX",ExpressionUUID->"2a0eb0f2-956a-4df9-86c9-253439cee8f4"],
Cell[60277, 1810, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"cfc64473-9335-4d46-af9e-4e11f747f717"],
Cell[60397, 1812, 93, 0, 70, "renderedTeX",ExpressionUUID->"b887baec-51c5-4ef5-8e77-ea0f8f5401d0"],
Cell[60493, 1814, 124, 0, 70, "label-llmComment",ExpressionUUID->"bdee635a-9ebc-4a21-b86b-f28dc06badb3"],
Cell[60620, 1816, 179, 3, 70, "LLMComment",ExpressionUUID->"706691b7-77a3-4939-82de-a3cd17a0b284"],
Cell[60802, 1821, 164, 3, 70, "label-formattedWL",ExpressionUUID->"c6a15bf1-cf42-478a-a16f-c891d07892ed"],
Cell[60969, 1826, 653, 22, 70, "formattedWL",ExpressionUUID->"15c7b6b0-e5ef-4b12-b427-f7fcc84dbfa2"],
Cell[61625, 1850, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"94d4d9e9-04c3-44c0-9cdc-b4ad4e2f52f4"],
Cell[61757, 1852, 767, 25, 70, "linearizedWL",ExpressionUUID->"7a0390fa-5d2b-4a89-95b0-2879671e10db"]
}, Open  ]],
Cell[CellGroupData[{
Cell[62561, 1882, 174, 4, 70, "Subsubsection",ExpressionUUID->"73e41274-3475-4712-9d51-9d276f111618"],
Cell[62738, 1888, 100, 0, 70, "arXivLabel",ExpressionUUID->"29d9ecbc-334a-41c0-85c8-10c40af90beb"],
Cell[62841, 1890, 184, 5, 70, "rawTeX",ExpressionUUID->"e6eba17e-5473-402a-b591-14af8566f01b"],
Cell[63028, 1897, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"670b86a7-cd0e-493b-85b6-2077375380b2"],
Cell[63148, 1899, 93, 0, 70, "renderedTeX",ExpressionUUID->"1d500c8b-da0c-4ad5-8de2-24f85a151d46"],
Cell[63244, 1901, 124, 0, 70, "label-llmComment",ExpressionUUID->"4f30a8fc-f2de-414f-a14a-9a5055c5d072"],
Cell[63371, 1903, 185, 3, 70, "LLMComment",ExpressionUUID->"ae09e91c-e1e1-4e88-831b-b7277de6fb26"],
Cell[63559, 1908, 164, 3, 70, "label-formattedWL",ExpressionUUID->"c4a0d941-eceb-4998-8eea-e0950af8bdb2"],
Cell[63726, 1913, 616, 19, 70, "formattedWL",ExpressionUUID->"a7f016e7-ff51-4a40-8d1c-1768f8768049"],
Cell[64345, 1934, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"1845bd79-249b-4f9d-88b6-455bf2c3301c"],
Cell[64477, 1936, 820, 25, 70, "linearizedWL",ExpressionUUID->"bc183828-651d-4546-bbd3-b489233ed8d6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65334, 1966, 174, 4, 70, "Subsubsection",ExpressionUUID->"8133a1ed-1349-492c-bcb2-8f5c85a21c71"],
Cell[65511, 1972, 100, 0, 70, "arXivLabel",ExpressionUUID->"0a2abe2d-5027-4437-a7b1-f745379167dd"],
Cell[65614, 1974, 402, 9, 70, "rawTeX",ExpressionUUID->"5c7ea17f-8be6-4c42-b9f8-e6adba1e9ceb"],
Cell[66019, 1985, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"0658a880-07a1-41c7-9b23-3c700bafcbaf"],
Cell[66139, 1987, 93, 0, 70, "renderedTeX",ExpressionUUID->"4c666770-0bf9-4a6f-a83c-61733ca6a9c5"],
Cell[66235, 1989, 124, 0, 70, "label-llmComment",ExpressionUUID->"122d4bf5-5a4f-4002-a873-42608bf735de"],
Cell[66362, 1991, 179, 3, 70, "LLMComment",ExpressionUUID->"f2e478e1-fb16-41b5-96ef-49d014a4151d"],
Cell[66544, 1996, 164, 3, 70, "label-formattedWL",ExpressionUUID->"f52956a6-c48c-418e-9d10-e269fc0cdc8b"],
Cell[66711, 2001, 1014, 32, 70, "formattedWL",ExpressionUUID->"144a8b8c-fc5f-440a-9658-32e3563b1d44"],
Cell[67728, 2035, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"91a85317-90bc-439c-a39d-25f8e7bcd706"],
Cell[67860, 2037, 1272, 38, 70, "linearizedWL",ExpressionUUID->"f4aaaf54-c5f6-48a9-868e-48d88a87dd45"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69169, 2080, 174, 4, 70, "Subsubsection",ExpressionUUID->"7376881b-ee86-4ea2-a766-3b3c1597f59a"],
Cell[69346, 2086, 100, 0, 70, "arXivLabel",ExpressionUUID->"34b01201-8cdb-46fc-b975-22451375c7c6"],
Cell[69449, 2088, 180, 5, 70, "rawTeX",ExpressionUUID->"ff1e3876-f77e-4729-bad1-204304aeb6fe"],
Cell[69632, 2095, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"85d61e9a-b264-4793-83b6-1c686ca84c42"],
Cell[69752, 2097, 93, 0, 70, "renderedTeX",ExpressionUUID->"46cb741f-4174-40e5-b3f5-26762fce2a3d"],
Cell[69848, 2099, 124, 0, 70, "label-llmComment",ExpressionUUID->"74c90bb3-499d-457e-afb3-c7b1f2935045"],
Cell[69975, 2101, 235, 7, 70, "LLMComment",ExpressionUUID->"075b68ad-c28e-49d9-b4dc-bab709786d50"],
Cell[70213, 2110, 164, 3, 70, "label-formattedWL",ExpressionUUID->"f1c573d9-d20e-4788-85b0-7d2fbf1c87f5"],
Cell[70380, 2115, 818, 27, 70, "formattedWL",ExpressionUUID->"c8af3db5-cb18-4aac-88df-f9066c967d64"],
Cell[71201, 2144, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"33d9a9c9-1a0b-44ad-8375-22a42a2d98bb"],
Cell[71333, 2146, 967, 30, 70, "linearizedWL",ExpressionUUID->"119a0af0-37a6-470e-abd2-a344486d6df7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72337, 2181, 166, 4, 70, "Subsubsection",ExpressionUUID->"21518339-73c1-44c0-a60f-56dab297d8c0"],
Cell[72506, 2187, 100, 0, 70, "arXivLabel",ExpressionUUID->"0581b741-8bcd-4ed0-b8b4-13a3cd08e9b8"],
Cell[72609, 2189, 236, 6, 70, "rawTeX",ExpressionUUID->"7ab24720-e405-4fd2-9b51-52f572f6f341"],
Cell[72848, 2197, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"9bd652cd-ef92-4b70-a65c-abd40695d1bd"],
Cell[72968, 2199, 93, 0, 70, "renderedTeX",ExpressionUUID->"313afa3b-95c8-443e-85ed-cc2d9fcb4e91"],
Cell[73064, 2201, 124, 0, 70, "label-llmComment",ExpressionUUID->"c46736db-600b-437f-82d0-37f42c5269be"],
Cell[73191, 2203, 247, 4, 70, "LLMComment",ExpressionUUID->"25f0afaa-ad32-4a61-95d1-abd2297e0735"],
Cell[73441, 2209, 164, 3, 70, "label-formattedWL",ExpressionUUID->"904b7dcc-6379-4131-a1f0-50dda51b33e0"],
Cell[73608, 2214, 833, 27, 70, "formattedWL",ExpressionUUID->"337c7bb8-8597-438c-812e-65d25ca76ac8"],
Cell[74444, 2243, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"de791c4e-455e-4304-9f76-57c69721db9d"],
Cell[74576, 2245, 1128, 34, 70, "linearizedWL",ExpressionUUID->"522350b0-3eac-4d35-878e-40e3f6aaffda"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75741, 2284, 174, 4, 70, "Subsubsection",ExpressionUUID->"46a4fc8f-0ebe-468a-89bf-b988f059e195"],
Cell[75918, 2290, 100, 0, 70, "arXivLabel",ExpressionUUID->"938818fd-88c5-4c01-8874-f781525eb932"],
Cell[76021, 2292, 178, 5, 70, "rawTeX",ExpressionUUID->"daf35ea3-6722-4869-ae2a-e1402aed3d32"],
Cell[76202, 2299, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"e6af4f6d-9cce-4a5d-b72e-c7957e00b11e"],
Cell[76322, 2301, 93, 0, 70, "renderedTeX",ExpressionUUID->"3949540d-c009-4f41-80fe-7c70a3cdfce2"],
Cell[76418, 2303, 124, 0, 70, "label-llmComment",ExpressionUUID->"9264d311-4f75-4db9-bf6c-5800499f9439"],
Cell[76545, 2305, 271, 4, 70, "LLMComment",ExpressionUUID->"964808c3-b818-44ac-bc78-b3796d3371c3"],
Cell[76819, 2311, 164, 3, 70, "label-formattedWL",ExpressionUUID->"0b2e3dea-04e6-4960-9f1a-e2e5007efa44"],
Cell[76986, 2316, 668, 21, 70, "formattedWL",ExpressionUUID->"a3fd9fe2-c72e-47db-b67d-526df7f42a4e"],
Cell[77657, 2339, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"eb78267b-ff68-4e06-a809-a9c253033ef4"],
Cell[77789, 2341, 884, 27, 70, "linearizedWL",ExpressionUUID->"e47921d0-1a52-4432-8779-c05ba72a960a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78710, 2373, 180, 4, 70, "Subsubsection",ExpressionUUID->"239cb556-1331-4a89-b59a-20d40b45e3e7"],
Cell[78893, 2379, 100, 0, 70, "arXivLabel",ExpressionUUID->"b830ce06-a129-48c3-b1bc-cbaca540f3fa"],
Cell[78996, 2381, 277, 6, 70, "rawTeX",ExpressionUUID->"2728f194-f028-4b41-ac67-acf2aec1eb91"],
Cell[79276, 2389, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"075f2b3b-e710-4d2c-aab0-e54ab47fcdb2"],
Cell[79396, 2391, 93, 0, 70, "renderedTeX",ExpressionUUID->"69545965-95b2-4364-9a5b-6efe5c7b2d95"],
Cell[79492, 2393, 124, 0, 70, "label-llmComment",ExpressionUUID->"a0797fb4-4abf-4883-97c1-2e3bba037bbf"],
Cell[79619, 2395, 320, 5, 70, "LLMComment",ExpressionUUID->"017a0042-90cf-4736-b32b-33538aac18eb"],
Cell[79942, 2402, 164, 3, 70, "label-formattedWL",ExpressionUUID->"2aaa3f5c-b52c-4bf8-8d20-fdc056ca641b"],
Cell[80109, 2407, 157, 3, 70, "formattedWL",ExpressionUUID->"05eab87b-12d6-4554-9c09-95354f9a0e0e"],
Cell[80269, 2412, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"e4598c8d-0039-4464-b08d-8bbe6a373f98"],
Cell[80401, 2414, 2399, 67, 70, "linearizedWL",ExpressionUUID->"ff5d450f-1024-486d-801c-e2bb130a3273"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[82849, 2487, 196, 5, 70, "Subsection",ExpressionUUID->"df3d0b01-3dcd-47b1-8bb5-0daeb258327f"],
Cell[CellGroupData[{
Cell[83070, 2496, 159, 4, 70, "Subsubsection",ExpressionUUID->"23114649-ce7f-49a3-8b7c-5ccbe887a6cf"],
Cell[83232, 2502, 100, 0, 70, "arXivLabel",ExpressionUUID->"3b44a57c-b771-4fcb-9f28-da47dc27182f"],
Cell[83335, 2504, 216, 6, 70, "rawTeX",ExpressionUUID->"8ffb58e6-7e93-468d-87ed-6723e28c4393"],
Cell[83554, 2512, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"ef4a963d-4832-44f2-b52f-e010fe43e421"],
Cell[83674, 2514, 93, 0, 70, "renderedTeX",ExpressionUUID->"4e02faca-d61b-4780-9460-3385b4f7fe41"],
Cell[83770, 2516, 124, 0, 70, "label-llmComment",ExpressionUUID->"9425e07e-8b75-488b-8f64-6c85feab8997"],
Cell[83897, 2518, 306, 4, 70, "LLMComment",ExpressionUUID->"573229e3-5cea-49c8-81cd-de4f9498420f"],
Cell[84206, 2524, 164, 3, 70, "label-formattedWL",ExpressionUUID->"f0e58120-aeaf-41fb-ace9-5bc6585ba8f9"],
Cell[84373, 2529, 684, 23, 70, "formattedWL",ExpressionUUID->"05b1a532-0102-4d12-bd69-6a22d6abceb2"],
Cell[85060, 2554, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"5b730e5a-fdcd-44ec-ac93-19991efcda02"],
Cell[85192, 2556, 762, 25, 70, "linearizedWL",ExpressionUUID->"0c4c23e4-00c4-4f83-9463-f76e6ebcaf0b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85991, 2586, 160, 4, 70, "Subsubsection",ExpressionUUID->"2fd2ab76-9759-477a-9c60-8c0fafb294db"],
Cell[86154, 2592, 100, 0, 70, "arXivLabel",ExpressionUUID->"039460b5-0ab9-46eb-812b-127d69d726a4"],
Cell[86257, 2594, 242, 6, 70, "rawTeX",ExpressionUUID->"92bbef96-2176-4d62-b37d-bcaaefaeac56"],
Cell[86502, 2602, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"e15ae892-d1fd-4017-9726-6016554109b4"],
Cell[86622, 2604, 93, 0, 70, "renderedTeX",ExpressionUUID->"1ac017af-74a6-4fc3-814a-83f315100b94"],
Cell[86718, 2606, 124, 0, 70, "label-llmComment",ExpressionUUID->"7bc78534-75f0-4c8e-8e72-38261ab1e5c6"],
Cell[86845, 2608, 288, 4, 70, "LLMComment",ExpressionUUID->"16f02d13-0e7f-47e3-b74b-ea06d5ad067e"],
Cell[87136, 2614, 164, 3, 70, "label-formattedWL",ExpressionUUID->"00a71bd4-ebb6-4529-86f1-c4b21f17706f"],
Cell[87303, 2619, 809, 28, 70, "formattedWL",ExpressionUUID->"9da1e4ab-def4-465d-8ee3-6aad10b7644b"],
Cell[88115, 2649, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"67f058cd-1aa0-4b66-ab71-e49b8bec96fd"],
Cell[88247, 2651, 955, 31, 70, "linearizedWL",ExpressionUUID->"eb5246a8-3d78-4909-a0b3-d5782a717709"]
}, Open  ]],
Cell[CellGroupData[{
Cell[89239, 2687, 160, 4, 70, "Subsubsection",ExpressionUUID->"5e39e5a9-2bb7-4b7c-b11e-28ace3d40239"],
Cell[89402, 2693, 100, 0, 70, "arXivLabel",ExpressionUUID->"abf8e004-3a8d-4759-ab22-2671f77a7698"],
Cell[89505, 2695, 250, 6, 70, "rawTeX",ExpressionUUID->"66c27dc1-b64d-4840-acd5-d036a0cb67c8"],
Cell[89758, 2703, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"17aba49c-59be-4329-bd4e-dad7128d9420"],
Cell[89878, 2705, 93, 0, 70, "renderedTeX",ExpressionUUID->"3a954e72-0f93-491c-a117-b48afa02d87b"],
Cell[89974, 2707, 124, 0, 70, "label-llmComment",ExpressionUUID->"bf3d4ebb-bcfd-4c6e-a238-e1b65bb21bd5"],
Cell[90101, 2709, 343, 9, 70, "LLMComment",ExpressionUUID->"8060983d-11ea-4a3b-acdc-b8e1e3759561"],
Cell[90447, 2720, 164, 3, 70, "label-formattedWL",ExpressionUUID->"1481c266-ee67-4e23-bec2-ec6a5f5d68a9"],
Cell[90614, 2725, 922, 32, 70, "formattedWL",ExpressionUUID->"1bfc90f9-5e40-4d70-9a5e-a5c76b5e9213"],
Cell[91539, 2759, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"af9c8530-0269-49da-ba77-3b0e2068c3d5"],
Cell[91671, 2761, 1136, 38, 70, "linearizedWL",ExpressionUUID->"7e5fb350-3dcd-4a3f-a3b6-2ef6cd446a4d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[92844, 2804, 159, 4, 70, "Subsubsection",ExpressionUUID->"1c7e57ce-36e2-4154-b5d9-7bfbd3450198"],
Cell[93006, 2810, 100, 0, 70, "arXivLabel",ExpressionUUID->"e1d4b710-48b5-41c2-b672-35d7454ca0a6"],
Cell[93109, 2812, 287, 8, 70, "rawTeX",ExpressionUUID->"64cb57fb-0147-4045-98d8-c4aa3927b7a8"],
Cell[93399, 2822, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"33913e6e-c639-49e8-9e1a-de3ddd8be5ef"],
Cell[93519, 2824, 93, 0, 70, "renderedTeX",ExpressionUUID->"669f0d91-d947-4ecf-8e59-a70cf805014b"],
Cell[93615, 2826, 124, 0, 70, "label-llmComment",ExpressionUUID->"653c1d63-a3f7-4492-9368-dd47a34547c8"],
Cell[93742, 2828, 358, 5, 70, "LLMComment",ExpressionUUID->"1688b4ad-f89f-4d08-a355-342f559bbc4c"],
Cell[94103, 2835, 164, 3, 70, "label-formattedWL",ExpressionUUID->"b7fc341d-4480-4b8d-b2a8-c467cb9ba750"],
Cell[94270, 2840, 1786, 53, 70, "formattedWL",ExpressionUUID->"e0bacb7e-5304-4111-a421-4144f9654225"],
Cell[96059, 2895, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"c090b2a4-4b55-4174-b1f3-d4721181ee8e"],
Cell[96191, 2897, 2227, 63, 70, "linearizedWL",ExpressionUUID->"3e4e2ddc-18b7-4e98-9944-74176ac8e825"]
}, Open  ]],
Cell[CellGroupData[{
Cell[98455, 2965, 159, 4, 70, "Subsubsection",ExpressionUUID->"e7f7a92b-c86a-45e5-a1d2-9d68fc040f49"],
Cell[98617, 2971, 100, 0, 70, "arXivLabel",ExpressionUUID->"ffe9b93b-894c-4220-a72c-2c89d8464ab6"],
Cell[98720, 2973, 265, 7, 70, "rawTeX",ExpressionUUID->"0a23a5bd-d595-4e4c-935a-9411ce205103"],
Cell[98988, 2982, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"3568e317-2333-4594-9a7f-3da467d728a7"],
Cell[99108, 2984, 93, 0, 70, "renderedTeX",ExpressionUUID->"b5c37d99-e13b-4f69-8912-57e30d57dfe1"],
Cell[99204, 2986, 124, 0, 70, "label-llmComment",ExpressionUUID->"9d4c66c7-bfd4-46a3-be50-baec413a6924"],
Cell[99331, 2988, 444, 10, 70, "LLMComment",ExpressionUUID->"951fe505-8047-4b94-9976-3512daa516e4"],
Cell[99778, 3000, 164, 3, 70, "label-formattedWL",ExpressionUUID->"69fc595b-1a51-49b5-9559-0590d343711b"],
Cell[99945, 3005, 1706, 51, 70, "formattedWL",ExpressionUUID->"b0e8b98b-ab29-4252-9a97-1dc2970bee98"],
Cell[101654, 3058, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"10a5eb70-9cb1-454d-9d79-5ff3ab83a383"],
Cell[101786, 3060, 2289, 66, 70, "linearizedWL",ExpressionUUID->"a26dfb2c-9924-4814-8856-ac6f9b93d27d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[104112, 3131, 149, 4, 70, "Subsubsection",ExpressionUUID->"c644a37e-6cf4-4205-baf3-e7fe9574553c"],
Cell[104264, 3137, 100, 0, 70, "arXivLabel",ExpressionUUID->"632afbb0-7ef1-4afb-b8cb-e55df9c2a23f"],
Cell[104367, 3139, 285, 6, 70, "rawTeX",ExpressionUUID->"1b378b0b-1948-4a5d-b19f-6175deae2beb"],
Cell[104655, 3147, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"3304ed77-e39a-4b6d-b888-40d4f1db850f"],
Cell[104775, 3149, 93, 0, 70, "renderedTeX",ExpressionUUID->"cd422661-a3e3-4b9e-ab1d-f1b2fdb80499"],
Cell[104871, 3151, 124, 0, 70, "label-llmComment",ExpressionUUID->"6d55d083-579d-41a9-b315-66d5eb6cac97"],
Cell[104998, 3153, 223, 3, 70, "LLMComment",ExpressionUUID->"f7b5f0a5-50fc-48c7-bdac-9ef44a0e9dad"],
Cell[105224, 3158, 164, 3, 70, "label-formattedWL",ExpressionUUID->"9efd7b95-7200-4dd7-b438-045fb9d1811a"],
Cell[105391, 3163, 1556, 50, 70, "formattedWL",ExpressionUUID->"08d61b2d-0f2d-497d-ab2a-0547af6536d9"],
Cell[106950, 3215, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"438abdfe-3ca5-4008-958c-b0143144f4b9"],
Cell[107082, 3217, 2354, 66, 70, "linearizedWL",ExpressionUUID->"7a7de70d-2df6-4e92-b8c4-e7ef9b567850"]
}, Open  ]],
Cell[CellGroupData[{
Cell[109473, 3288, 186, 4, 70, "Subsubsection",ExpressionUUID->"b882febe-0089-4650-97ee-a95e0539fb22"],
Cell[109662, 3294, 100, 0, 70, "arXivLabel",ExpressionUUID->"1e26d4e4-5cfe-4d41-a85e-0aafdffb5743"],
Cell[109765, 3296, 215, 5, 70, "rawTeX",ExpressionUUID->"18d6d97b-669c-4317-aea3-0cc3e91f74ce"],
Cell[109983, 3303, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"c0c596e4-f565-4f8c-981a-0d7472396095"],
Cell[110103, 3305, 93, 0, 70, "renderedTeX",ExpressionUUID->"bd9b9596-663b-4408-8dff-e0e29eaea844"],
Cell[110199, 3307, 124, 0, 70, "label-llmComment",ExpressionUUID->"60379663-7681-42b0-aaf3-0d5deb8ca2b0"],
Cell[110326, 3309, 225, 3, 70, "LLMComment",ExpressionUUID->"75b38180-8cfd-406e-a70c-84e58b0dc774"],
Cell[110554, 3314, 164, 3, 70, "label-formattedWL",ExpressionUUID->"3d9a3d78-0803-4b2e-9efc-03678fe570e6"],
Cell[110721, 3319, 1162, 37, 70, "formattedWL",ExpressionUUID->"6805c283-9881-4820-8539-e748e39b512e"],
Cell[111886, 3358, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"fc68aa08-8901-46cb-b0bb-a3ead370a9c1"],
Cell[112018, 3360, 1562, 45, 70, "linearizedWL",ExpressionUUID->"fd126ba0-dcb2-4f10-8440-65b4dcae336b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113617, 3410, 169, 4, 70, "Subsubsection",ExpressionUUID->"13c234f8-3584-43ac-87df-5f0e3e6eae97"],
Cell[113789, 3416, 100, 0, 70, "arXivLabel",ExpressionUUID->"15ec20ef-1506-4eb0-8d42-9e9d14723822"],
Cell[113892, 3418, 200, 5, 70, "rawTeX",ExpressionUUID->"39e02b9f-1199-4a1f-bbae-c49875fd7c8e"],
Cell[114095, 3425, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"61309ae5-aaa0-4c71-8580-1790ec173bc0"],
Cell[114215, 3427, 93, 0, 70, "renderedTeX",ExpressionUUID->"7c273241-65b2-4033-8579-80bf5840d3e5"],
Cell[114311, 3429, 124, 0, 70, "label-llmComment",ExpressionUUID->"994e2a05-cdee-4618-b27d-52a113d1d1d9"],
Cell[114438, 3431, 263, 4, 70, "LLMComment",ExpressionUUID->"93b27fad-28ec-4c44-b3f9-6d23c0decb27"],
Cell[114704, 3437, 164, 3, 70, "label-formattedWL",ExpressionUUID->"bd795add-12bf-446c-a2bb-4ceae985ae1e"],
Cell[114871, 3442, 997, 32, 70, "formattedWL",ExpressionUUID->"c98fd389-f27b-4091-bf80-13b9681c2b95"],
Cell[115871, 3476, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"a0afa225-d9df-4f42-8fc7-4440d9768095"],
Cell[116003, 3478, 1447, 42, 70, "linearizedWL",ExpressionUUID->"15f3a7d6-f9f2-4db8-b702-222efec6c822"]
}, Open  ]],
Cell[CellGroupData[{
Cell[117487, 3525, 155, 4, 70, "Subsubsection",ExpressionUUID->"c381b705-66a5-4350-bda9-bf65bbcf7559"],
Cell[117645, 3531, 100, 0, 70, "arXivLabel",ExpressionUUID->"82dccd4d-e29d-4983-a0f5-c225d4653e14"],
Cell[117748, 3533, 436, 11, 70, "rawTeX",ExpressionUUID->"65b33d7a-2ac4-4a49-af3c-37d3f29e50e4"],
Cell[118187, 3546, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"d8d50538-6663-486b-9501-c1e3d8704fbc"],
Cell[118307, 3548, 93, 0, 70, "renderedTeX",ExpressionUUID->"f1d88d18-2e9a-499a-8934-6ea39908e956"],
Cell[118403, 3550, 124, 0, 70, "label-llmComment",ExpressionUUID->"01bc9bd7-5ecc-4f77-b623-a96d854fd3ab"],
Cell[118530, 3552, 322, 5, 70, "LLMComment",ExpressionUUID->"255bdca9-5f84-4f85-9ac1-d023164bb8e8"],
Cell[118855, 3559, 164, 3, 70, "label-formattedWL",ExpressionUUID->"5a171ae9-8e28-4220-99d8-164a4538b65e"],
Cell[119022, 3564, 2361, 68, 70, "formattedWL",ExpressionUUID->"fe3ca6f3-2b54-47b3-8c9f-f0d1b8c79522"],
Cell[121386, 3634, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"27a924c9-c693-474d-b110-93dcc011c949"],
Cell[121518, 3636, 3600, 96, 70, "linearizedWL",ExpressionUUID->"0d9fd925-98fc-4a48-a6c5-bde101f5ec84"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[125167, 3738, 150, 3, 70, "Subsection",ExpressionUUID->"9ef3c4d2-70c2-4202-bee7-7e5d555849e0"],
Cell[CellGroupData[{
Cell[125342, 3745, 163, 4, 70, "Subsubsection",ExpressionUUID->"aefc1fcc-582a-4d1a-9dab-0b29af878a34"],
Cell[125508, 3751, 100, 0, 70, "arXivLabel",ExpressionUUID->"c2519120-75ec-4ca3-8d0f-9bf48af1a440"],
Cell[125611, 3753, 140, 4, 70, "rawTeX",ExpressionUUID->"b0292cec-b259-4afa-b49d-593a01a751e0"],
Cell[125754, 3759, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"37efff32-9996-456f-b686-8d4efe01435b"],
Cell[125874, 3761, 93, 0, 70, "renderedTeX",ExpressionUUID->"46af489c-bf9c-46d2-a917-5a405274cd84"],
Cell[125970, 3763, 124, 0, 70, "label-llmComment",ExpressionUUID->"28b4d295-ad98-4590-b1ab-995b9e9df5ba"],
Cell[126097, 3765, 270, 4, 70, "LLMComment",ExpressionUUID->"ed778df7-ac9e-419a-bba1-481704353f59"],
Cell[126370, 3771, 164, 3, 70, "label-formattedWL",ExpressionUUID->"2749b5fe-8c69-4964-8888-a22d25c781c0"],
Cell[126537, 3776, 503, 16, 70, "formattedWL",ExpressionUUID->"7bff41b7-5848-49ef-be87-14b69d9896d8"],
Cell[127043, 3794, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"7a3e112f-de53-4421-9c78-8a7e86128087"],
Cell[127175, 3796, 621, 19, 70, "linearizedWL",ExpressionUUID->"41841e98-ecc4-4530-b698-9270511ffc92"]
}, Open  ]],
Cell[CellGroupData[{
Cell[127833, 3820, 155, 4, 70, "Subsubsection",ExpressionUUID->"e6941164-0356-4312-9be6-71a5f65ac2ce"],
Cell[127991, 3826, 100, 0, 70, "arXivLabel",ExpressionUUID->"cae88792-c1ef-45a8-99d5-11f6ce4f082b"],
Cell[128094, 3828, 331, 10, 70, "rawTeX",ExpressionUUID->"3773ebfe-4f45-4903-abc1-aea4e727724d"],
Cell[128428, 3840, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"b8d88ab4-1425-4462-b5cd-cba9830d43dd"],
Cell[128548, 3842, 3698, 89, 70, "renderedTeX",ExpressionUUID->"39b0e326-1abb-4a8c-a857-fdd695b32e13"],
Cell[132249, 3933, 124, 0, 70, "label-llmComment",ExpressionUUID->"b7808628-2829-44b7-bdb6-e5969d431657"],
Cell[132376, 3935, 318, 5, 70, "LLMComment",ExpressionUUID->"404b7451-d387-445d-a24a-d1e35d26d5b0"],
Cell[132697, 3942, 164, 3, 70, "label-formattedWL",ExpressionUUID->"b47c1c4d-7320-44d6-846c-d0ba51975d40"],
Cell[132864, 3947, 1348, 43, 70, "formattedWL",ExpressionUUID->"5ab111ff-8e31-40be-8193-92c91ed374fb"],
Cell[134215, 3992, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"8104ff36-7689-4954-977b-1f1820324e02"],
Cell[134347, 3994, 1674, 52, 70, "linearizedWL",ExpressionUUID->"df8b6e8c-0557-49a1-b273-f7f2c419f41d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[136058, 4051, 164, 4, 70, "Subsubsection",ExpressionUUID->"8d35f020-757f-4c35-937e-c3d1c1eec368"],
Cell[136225, 4057, 100, 0, 70, "arXivLabel",ExpressionUUID->"9f479ab5-d4da-4289-ac4a-6dc793782077"],
Cell[136328, 4059, 483, 12, 70, "rawTeX",ExpressionUUID->"f4b38c87-4fd1-405d-9b3d-6e5e1f2352ba"],
Cell[136814, 4073, 117, 0, 70, "label-renderedTeX",ExpressionUUID->"ef096b53-4fcb-4df1-b89b-3ad894c92319"],
Cell[136934, 4075, 6265, 160, 70, "renderedTeX",ExpressionUUID->"b8a34d01-ef47-4494-8793-06ccb59c9e1e"],
Cell[143202, 4237, 124, 0, 70, "label-llmComment",ExpressionUUID->"8106a7d2-ac53-4c81-ad3f-cecee7fab68d"],
Cell[143329, 4239, 419, 6, 70, "LLMComment",ExpressionUUID->"2a452af6-6494-45ca-a223-5f6ff9bb8b3f"],
Cell[143751, 4247, 164, 3, 70, "label-formattedWL",ExpressionUUID->"d3cc8eaa-78c2-49b9-b299-f41216ee948e"],
Cell[143918, 4252, 4291, 121, 70, "formattedWL",ExpressionUUID->"43437700-4b0b-493c-af60-05a8b0189f43"],
Cell[148212, 4375, 129, 0, 70, "label-linearizedWL",ExpressionUUID->"58ab4e50-7897-485c-880d-81da2246d751"],
Cell[148344, 4377, 5070, 132, 70, "linearizedWL",ExpressionUUID->"a17730c8-a0a2-493c-a37c-3cc20ef518a2"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

